local _, core = ...;
core.wccreator = {};
local WCC_UI;
local MainSettingsGuide_UI = {};
local MainSettingsGuide_UIFrame;
local onCreator = false;
local WC_Draggable = nil;
local UIConf = nil;

function GetLocalNumberByLocalID()
	local l = GetLocale();
	for i = 1, #core.L["LangID"] do
		if (core.L["LangID"][i] == l) then
			return i;
		end
	end
	return 1;
end

function WCCreator_Lib.OnClick_ShowWCC()	
	WC_Draggable = _G["WC_Draggable"];
	UIConf       = _G["WoWChallengerFrame"];
	local menu = WCC_UI or core.wccreator.CreateWCC_UI();
	if (menu:IsShown()) then
		PlaySound("31582", "sfx");
		menu:Hide();
		UIConf:SetShown(true);
		OnCreator = false;
	elseif (not menu:IsShown()) then
		PlaySound("31582", "sfx");
		menu:SetPoint("CENTER", WC_Draggable, "CENTER");
		UIConf:Hide();
		menu:SetShown(true);
		OnCreator = true;
	end
end

function WCCreator_Lib.GenerateIDGuide()
    local template ='xxxxxxxxxxxx'
    return string.gsub(template, '[xy]', function (c)
        local v = (c == 'x') and math.random(0, 0xf) or math.random(8, 0xb)
        return string.format('%x', v)
    end)
end

local function CheckIfErrorExists()
	local settings     = WCCreator_Lib.structures.MainSettings_value;
	local bOk          = true;
	local messageError = "";
	if (settings.category == "hf" and not MainSettingsGuide_UIFrame.tb_IdAchievValid:IsShown()) then
		messageError = messageError.."- "..core.L["ID Haut-fait"].." : |cffff0000"..core.L["Champ non validé."].."|r";
		bOk = false;
	elseif (settings.category == "mounts" and not MainSettingsGuide_UIFrame.tb_IdMountsValid:IsShown()) then
		messageError = messageError.."- "..core.L["ID Monture"].." : |cffff0000"..core.L["Champ non validé."].."|r";
		bOk = false;
	elseif (settings.category == "pets" and not MainSettingsGuide_UIFrame.tb_IdPetsValid:IsShown()) then
		messageError = messageError.."- "..core.L["ID Mascotte"].." : |cffff0000"..core.L["Champ non validé."].."|r";
		bOk = false;
	elseif (settings.category == "transmogs" and not MainSettingsGuide_UIFrame.tb_IdTransmogsValid:IsShown()) then
		messageError = messageError.."- "..core.L["ID Objet"].." : |cffff0000"..core.L["Champ non validé."].."|r";
		bOk = false;
	end
	if (settings.category == "transmogs") then
		if (settings.modID ~= nil and settings.modID ~= "" and tonumber(settings.modID) >= 2147483647) then
			messageError = messageError.."- "..core.L["ModID"].." : |cffff0000"..core.L["Nombre trop élevé."].." (<2147483647)|r";
			bOk = false;
		end
	elseif (settings.category ~= "hf") then
		if (settings.displayID ~= nil and settings.displayID ~= "" and tonumber(settings.displayID) >= 2147483647) then
			messageError = messageError.."- "..core.L["DisplayID"].." : |cffff0000"..core.L["Nombre trop élevé."].." (<2147483647)|r";
			bOk = false;
		end
	end
	return unpack({bOk, messageError});
end

local function SaveGuide()
	if (CheckIfErrorExists() == true) then
		local MS = WCCreator_Lib.structures.MainSettings_value;
		local currentGuide = {};
		currentGuide.id = MS.id;
		currentGuide.idGuide = MS.idGuide;
		currentGuide.category = MS.category;
		currentGuide.faction = MS.faction;
		currentGuide.info = {MS.name, MS.isCollected, MS.description, MS.location};
		currentGuide.icon = MS.iconID;
		currentGuide.Model = {id = tonumber(MS.displayID), modID = MS.modID, camDist = 1, rotation = 1, bOnPlayer = MS.bOnPlayer};
		if (currentGuide.category == "transmogs") then
			currentGuide.Model.id = MS.id;
		end
		currentGuide.expansion = MS.expansion;
		currentGuide.difficulty = MS.difficulty;
		currentGuide.class = {};
		currentGuide.lang = MS.lang;
		for i = 1, #MS.class do
			if (MS.class[i] == true) then
				currentGuide.class[#currentGuide.class+1] = i;
			end
		end
		currentGuide.av_settings = MS.av_settings;
		if (MS.idGuide == "") then
			currentGuide.idGuide = WCCreator_Lib.GenerateIDGuide();
			currentGuide.av_settings.createBy = UnitName("player").." - "..GetRealmName().." ("..date("%m/%d/%y %H:%M:%S")..")";
			currentGuide.av_settings.lastModified = "";
			currentGuide.page = {
			{icon = "Interface\\ICONS\\inv_misc_questionmark",
				rens = {
				{category = "NPC", displayID = "", title = core.L["Informations Cadre"], stepAssigned = "",
					onMap = {enable = false, pins = {}}} },
				step = {
				{help = "", important = false, task = { {taskType = "custom", title = core.L["Titre quête"], tooltipText = core.L["Description quête"]} } }}}};
				
			YourGuides[#YourGuides + 1] = currentGuide;
			ListGuides[#ListGuides + 1] = currentGuide.idGuide;
			PlaySound("39673", "sfx");
		else
			currentGuide.av_settings.version = currentGuide.av_settings.version + 1;
			currentGuide.av_settings.lastModified = UnitName("player").." - "..GetRealmName().." ("..date("%m/%d/%y %H:%M:%S")..")";
			currentGuide.page = YourGuides[WC_Lib.GetIndexGuideByID(currentGuide.idGuide, "WCC")].page;
			YourGuides[WC_Lib.GetIndexGuideByID(currentGuide.idGuide, "WCC")] = currentGuide;	
			g_guideSelected["WCC"] = "";
		end
		WC_Lib.RefreshListCollections("WCC");
		_G["WCC_GuidesCollection"..currentGuide.idGuide.."_Btn"]:Click();
	end
end


local tooltip_guidePreview = function(self, motion)
	GameTooltip:SetOwner(self, "ANCHOR_LEFT", 0, 0);
	local settings = WCCreator_Lib.structures.MainSettings_value;
	GameTooltip:AddLine(settings.name, 1, 1, 1);
	if (settings.isCollected == true) then
		GameTooltip:AddDoubleLine("|cff00ff00"..core.L["MountCollected"].."|r", core.L["Difficult"][settings.difficulty]);
	else
		GameTooltip:AddDoubleLine("|cffff0000"..core.L["MountNotCollected"].."|r", core.L["Difficult"][settings.difficulty]);
	end
	if (settings.description ~= nil and settings.description ~= "") then
		GameTooltip:AddLine("\""..settings.description.."\"", 1, 0.82, 0, true);
	end
	if (settings.location ~= nil and settings.location ~= "") then
		GameTooltip:AddLine(settings.location, 1, 1, 1);
	end
	local classStr = "";
	local allclass = true;
		for i = 1, #settings.class do
			if (settings.class[i] == true) then
				if (classStr == "") then
					classStr = classStr..core.L["ClassesList"][i];
				else
					classStr = classStr.."|cffffffff,|r "..core.L["ClassesList"][i];	
				end
			else
				allclass = false;
			end
		end
	if (classStr ~= "" and allclass == false) then
		GameTooltip:AddLine(core.L["Classes"]..core.L["2points"]..classStr, 1, 0.82, 0, true);
	end
	if (settings.expansion ~= "" and settings.expansion ~= nil) then
		GameTooltip:AddLine(core.L["Expansion"]..core.L["2points"].."|cffffffff"..settings.expansion.."|r");
	end
	GameTooltip:Show();
end

local ShowListErrorEditGuide = function(self, motion)
	local settings = WCCreator_Lib.structures.MainSettings_value;
	local bOk, messageError = CheckIfErrorExists();
	if (bOk == false) then
		GameTooltip:SetOwner(self, "ANCHOR_TOP", 0, 0);
		GameTooltip:AddLine(core.L["Informations incorrectes"], 1, 1, 1);
		GameTooltip:AddLine(messageError);
		GameTooltip:Show();
	end
end

local function CreatePreview(parent)
	local preview = CreateFrame("Frame", "WCC_MS_Preview", parent, BackdropTemplateMixin and "BackdropTemplate");
	preview:SetSize(230,75);
	preview:SetBackdrop({bgFile = "Interface/FrameGeneral/UI-Background-Marble",
							edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
							tile = true, edgeSize = 16, tileSize = 256,
							insets = { left = 3, right = 3, top = 3, bottom = 3 }});
	
	
	local iconGuidePreview = CreateFrame("Frame", "WCC_MS_PreviewIcon", preview, BackdropTemplateMixin and "BackdropTemplate");
	iconGuidePreview:SetSize(45, 45);
	iconGuidePreview:SetPoint("LEFT", preview, "LEFT", 4, 10);
	iconGuidePreview:SetBackdrop({bgFile = WCCreator_Lib.structures.MainSettings_value.iconID});
	iconGuidePreview:SetScript("OnEnter", tooltip_guidePreview);
	iconGuidePreview:SetScript("OnLeave", WC_Lib.OnLeave);
	
	local btnGuidePreview = CreateFrame("Button", nil, preview);
	btnGuidePreview:SetSize(175, 45);
	btnGuidePreview:SetPoint("LEFT", iconGuidePreview, "RIGHT", 0, 0);
	btnGuidePreview:SetNormalTexture("Interface/AddOns/WoWChallenger/images/mounts/button_mount");
	
	btnGuidePreview.bg_faction = CreateFrame("Frame", "WCC_MS_PreviewFaction", btnGuidePreview, BackdropTemplateMixin and "BackdropTemplate");
	btnGuidePreview.bg_faction:SetSize(57, 57);
	btnGuidePreview.bg_faction:SetPoint("RIGHT", btnGuidePreview, "RIGHT", 5, 0);
	if (WCCreator_Lib.structures.MainSettings_value.faction == 2) then
		btnGuidePreview.bg_faction:SetBackdrop({bgFile = "Interface/AddOns/WoWChallenger/images/mounts/button_bg_horde"});
	elseif (WCCreator_Lib.structures.MainSettings_value.faction == 1) then
		btnGuidePreview.bg_faction:SetBackdrop({bgFile = "Interface/AddOns/WoWChallenger/images/mounts/button_bg_alliance"});			
	end
	
	btnGuidePreview.bg_category = CreateFrame("Frame", "WCC_MS_PreviewCategory", btnGuidePreview, BackdropTemplateMixin and "BackdropTemplate");
	btnGuidePreview.bg_category:SetSize(22, 22);
	btnGuidePreview.bg_category:SetPoint("BOTTOMRIGHT", btnGuidePreview, "BOTTOMRIGHT", 0, 2);
	btnGuidePreview.bg_category:SetBackdrop({bgFile = "Interface/AddOns/WoWChallengerCREATOR/images/hf_category"});
	btnGuidePreview.bg_category.cat = "Hauts-faits";
	btnGuidePreview.bg_category:SetScript("OnEnter", function (self, motion)
								GameTooltip:SetOwner(self, "ANCHOR_RIGHT", 0, -15);
								GameTooltip:AddLine(self.cat);
								GameTooltip:Show();
								end);
	btnGuidePreview.bg_category:SetScript("OnLeave", WC_Lib.OnLeave);

	btnGuidePreview.text = btnGuidePreview:CreateFontString("WCC_MS_PreviewText", "OVERLAY", nil);
	btnGuidePreview.text:SetSize(btnGuidePreview:GetWidth()-20, 0);
	if (WCCreator_Lib.structures.MainSettings_value.isCollected == true) then
		btnGuidePreview.text:SetFontObject("GameFontGreen");
	else
		btnGuidePreview.text:SetFontObject("GameFontNormal");
	end
	btnGuidePreview.text:SetText(WCCreator_Lib.structures.MainSettings_value.name);
	btnGuidePreview.text:SetJustifyH("LEFT");
	btnGuidePreview.text:SetPoint("LEFT", btnGuidePreview, "LEFT", 10, 0);

	preview.btnSave = CreateFrame("Button", "WCC_MS_PreviewBtnSave", preview, "UIPanelButtonTemplate");
	preview.btnSave:SetSize(200, 23);
	preview.btnSave:SetText("Créer");
	preview.btnSave:SetPoint("BOTTOMLEFT", preview, "BOTTOMLEFT", 3, 4);
	preview.btnSave:SetScript("OnClick", SaveGuide);
	preview.btnSave:SetScript("OnLeave", WC_Lib.OnLeave);
	preview.btnSave:SetScript("OnEnter", ShowListErrorEditGuide);
	
	preview.helpIcon = CreateFrame("Frame", "WCC_MS_PreviewBtnHelp", preview, "UIPanelInfoButton");
	preview.helpIcon:SetSize(24, 24);
	preview.helpIcon:SetPoint("BOTTOMRIGHT", preview, "BOTTOMRIGHT", 0, 0);
	preview.helpIcon:SetScript("OnLeave", WC_Lib.OnLeave);
	preview.helpIcon:SetScript("OnEnter", WCCreator_Lib.tooltip.tooltip_av_settings);

	return preview;
end

------ MainSettingsGuide_UI ------
function MainSettingsGuide_UI:Create()
	MainSettingsGuide_UIFrame = CreateFrame("Frame", "WCC_MainParamGuide", WCC_UI, BackdropTemplateMixin and "BackdropTemplate");
	MainSettingsGuide_UIFrame:SetSize(555,450);
	MainSettingsGuide_UIFrame:SetPoint("BOTTOMRIGHT", WCC_UI, "BOTTOMRIGHT", -2, 2.5);
	MainSettingsGuide_UIFrame:SetBackdrop({bgFile = "Interface/Collections/CollectionsBackgroundTile",
							edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
							tile = true, edgeSize = 16, tileSize = 256,
							insets = { left = 0, right = 0, top = 0, bottom = 0 }});

	MainSettingsGuide_UIFrame.title = CreateFrame("Frame", "WCC_MainParamGuide_Title", MainSettingsGuide_UIFrame, BackdropTemplateMixin and "BackdropTemplate");
	MainSettingsGuide_UIFrame.title:SetSize(300,65);
	MainSettingsGuide_UIFrame.title:SetPoint("TOP", MainSettingsGuide_UIFrame, "TOP", 0, 0);
	MainSettingsGuide_UIFrame.title:SetBackdrop({bgFile = "Interface/AddOns/WoWChallengerCreator/images/bg_title_param"});
	MainSettingsGuide_UIFrame.Texttitle = MainSettingsGuide_UIFrame.title:CreateFontString("WCC_MainParamGuide_TitleText", "OVERLAY", "GameFontHighlightLarge");
	MainSettingsGuide_UIFrame.Texttitle:SetText(core.L["Nouveau guide"]);
	MainSettingsGuide_UIFrame.Texttitle:SetPoint("CENTER");
	
	MainSettingsGuide_UIFrame.ScrollFrame = CreateFrame("ScrollFrame", nil, MainSettingsGuide_UIFrame, "UIPanelScrollFrameTemplate");
	MainSettingsGuide_UIFrame.ScrollFrame:SetPoint("TOPLEFT", MainSettingsGuide_UIFrame, "TOPLEFT", 0, 0);
	MainSettingsGuide_UIFrame.ScrollFrame:SetPoint("BOTTOMRIGHT", MainSettingsGuide_UIFrame, "BOTTOMRIGHT", 0, 0);
	MainSettingsGuide_UIFrame.ScrollFrame:SetClipsChildren(true);
	MainSettingsGuide_UIFrame.ScrollFrame.ScrollBar:ClearAllPoints();
	MainSettingsGuide_UIFrame.ScrollFrame.ScrollBar:SetPoint("TOPRIGHT", MainSettingsGuide_UIFrame.ScrollFrame, "TOPRIGHT", -4, -20);
	MainSettingsGuide_UIFrame.ScrollFrame.ScrollBar:SetPoint("BOTTOMRIGHT", MainSettingsGuide_UIFrame.ScrollFrame, "BOTTOMRIGHT", -4, 20);
	local child = CreateFrame("Frame", "WCC_MainParamGuide_Scroll", MainSettingsGuide_UIFrame.ScrollFrame);
	child:SetSize(MainSettingsGuide_UIFrame:GetWidth(), MainSettingsGuide_UIFrame:GetHeight());
	MainSettingsGuide_UIFrame.ScrollFrame:SetScrollChild(child);
	MainSettingsGuide_UIFrame.ScrollFrame:SetScript("OnMouseWheel", WC_Lib.ScrollFrame_OnMouseWheel);
	
	-- ===== PARTIE INFO BASE =====
	MainSettingsGuide_UIFrame.title1 = WCCreator_Lib.CreateTitle(core.L["Informations basiques"], child);
	MainSettingsGuide_UIFrame.title1:SetPoint("TOP", child, "TOP", 0, -75);
		----- HF PART -----
	MainSettingsGuide_UIFrame.tb_IdAchiev = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_IdAchiev, child);
	MainSettingsGuide_UIFrame.tb_IdAchiev:SetPoint("CENTER", MainSettingsGuide_UIFrame.title1, "CENTER", 135, -50);
	MainSettingsGuide_UIFrame.tb_IdAchievValid = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_IdAchievValid, child);
	MainSettingsGuide_UIFrame.tb_IdAchievValid:SetPoint("CENTER", MainSettingsGuide_UIFrame.title1, "CENTER", 135, -50);
	WCCreator_Lib.TextBoxSetDisable(MainSettingsGuide_UIFrame.tb_IdAchievValid);
	MainSettingsGuide_UIFrame.tb_IdAchievValid:Hide();
		---- MOUNTS PART -----
	MainSettingsGuide_UIFrame.tb_IdMounts = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_IdMounts, child);
	MainSettingsGuide_UIFrame.tb_IdMounts:SetPoint("CENTER", MainSettingsGuide_UIFrame.title1, "CENTER", 135, -50);
	MainSettingsGuide_UIFrame.tb_IdMountsValid = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_IdMountsValid, child);
	MainSettingsGuide_UIFrame.tb_IdMountsValid:SetPoint("CENTER", MainSettingsGuide_UIFrame.title1, "CENTER", 135, -50);
	MainSettingsGuide_UIFrame.tb_IdMounts:Hide();
	WCCreator_Lib.TextBoxSetDisable(MainSettingsGuide_UIFrame.tb_IdMountsValid);
	MainSettingsGuide_UIFrame.tb_IdMountsValid:Hide();
		---- PETS PART -----
	MainSettingsGuide_UIFrame.tb_IdPets = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_IdPets, child);
	MainSettingsGuide_UIFrame.tb_IdPets:SetPoint("CENTER", MainSettingsGuide_UIFrame.title1, "CENTER", 135, -50);
	MainSettingsGuide_UIFrame.tb_IdPetsValid = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_IdPetsValid, child);
	MainSettingsGuide_UIFrame.tb_IdPetsValid:SetPoint("CENTER", MainSettingsGuide_UIFrame.title1, "CENTER", 135, -50);
	MainSettingsGuide_UIFrame.tb_IdPets:Hide();
	WCCreator_Lib.TextBoxSetDisable(MainSettingsGuide_UIFrame.tb_IdPetsValid);
	MainSettingsGuide_UIFrame.tb_IdPetsValid:Hide();
		---- TRANSMOGS PART -----
	MainSettingsGuide_UIFrame.tb_IdTransmogs = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_IdTransmogs, child);
	MainSettingsGuide_UIFrame.tb_IdTransmogs:SetPoint("CENTER", MainSettingsGuide_UIFrame.title1, "CENTER", 135, -50);
	MainSettingsGuide_UIFrame.tb_IdTransmogsValid = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_IdTransmogsValid, child);
	MainSettingsGuide_UIFrame.tb_IdTransmogsValid:SetPoint("CENTER", MainSettingsGuide_UIFrame.title1, "CENTER", 135, -50);
	MainSettingsGuide_UIFrame.tb_IdTransmogs:Hide();
	WCCreator_Lib.TextBoxSetDisable(MainSettingsGuide_UIFrame.tb_IdTransmogsValid);
	MainSettingsGuide_UIFrame.tb_IdTransmogsValid:Hide();
	
	MainSettingsGuide_UIFrame.ddm_Category = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Category, child);
	MainSettingsGuide_UIFrame.ddm_Category:SetPoint("CENTER", MainSettingsGuide_UIFrame.title1, "CENTER", -135, -50);
	
	-- ===== PARTIE INFO TEXTE =====
	MainSettingsGuide_UIFrame.title2 = WCCreator_Lib.CreateTitle(core.L["Informations textuelles"], child);
	MainSettingsGuide_UIFrame.title2:SetPoint("TOP", MainSettingsGuide_UIFrame.title1, "BOTTOM", 0, -90);
	MainSettingsGuide_UIFrame.tb_Name = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Name, child);
	MainSettingsGuide_UIFrame.tb_Name:SetPoint("CENTER", MainSettingsGuide_UIFrame.title2, "CENTER", 0, -50);
	MainSettingsGuide_UIFrame.tb_Name:SetText(core.L["Nouveau guide"]);
	MainSettingsGuide_UIFrame.multi_Desc = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Desc, child);
	MainSettingsGuide_UIFrame.multi_Desc:SetPoint("TOPLEFT", MainSettingsGuide_UIFrame.tb_Name, "BOTTOMLEFT", 0, -20);
	MainSettingsGuide_UIFrame.muli_Location = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Location, child);
	MainSettingsGuide_UIFrame.muli_Location:SetPoint("TOPRIGHT", MainSettingsGuide_UIFrame.tb_Name, "BOTTOMRIGHT", 0, -20);
	
	-- ===== PARTIE INFO GRAPHIQUE =====
	MainSettingsGuide_UIFrame.title3 = WCCreator_Lib.CreateTitle(core.L["Informations graphiques"], child);
	MainSettingsGuide_UIFrame.title3:SetPoint("TOP", MainSettingsGuide_UIFrame.title2, "BOTTOM", 0, -165);
	MainSettingsGuide_UIFrame.tb_DisplayID = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_DisplayID, child);
	MainSettingsGuide_UIFrame.tb_DisplayID:SetPoint("CENTER", MainSettingsGuide_UIFrame.title3, "CENTER", 135, -50);
	WCCreator_Lib.TextBoxSetDisable(MainSettingsGuide_UIFrame.tb_DisplayID);
	MainSettingsGuide_UIFrame.tb_DisplayID.button:Disable();
	MainSettingsGuide_UIFrame.tb_ModID = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_ModID, child);
	MainSettingsGuide_UIFrame.tb_ModID:SetPoint("CENTER", MainSettingsGuide_UIFrame.title3, "CENTER", 135, -50);
	MainSettingsGuide_UIFrame.tb_ModID:Hide();
	
	MainSettingsGuide_UIFrame.selectIcon = CreateFrame("Frame", nil, child, BackdropTemplateMixin and "BackdropTemplate");
	MainSettingsGuide_UIFrame.selectIcon:SetSize(74,74);
	MainSettingsGuide_UIFrame.selectIcon:SetBackdrop({bgFile = "Interface/Buttons/UI-Slot-Background"});

	MainSettingsGuide_UIFrame.selectIcon.interact = CreateFrame("Button", "WCC_MS_GuideIconInteract", MainSettingsGuide_UIFrame.selectIcon, BackdropTemplateMixin and "BackdropTemplate");
	MainSettingsGuide_UIFrame.selectIcon.interact:SetSize(47,47);
	MainSettingsGuide_UIFrame.selectIcon.interact:SetPoint("TOPLEFT");
	MainSettingsGuide_UIFrame.selectIcon.interact.func_iconSelect = WCCreator_Lib.structures.iconSelectorGuide.func;
	MainSettingsGuide_UIFrame.selectIcon.interact:SetScript("OnEnter", function(self)
									GameTooltip:SetOwner(self, "ANCHOR_TOP", 0, 0);
									GameTooltip:AddLine(core.L["Icone du guide"], 1, 1, 1);
									GameTooltip:AddLine("<"..core.L["Cliquer pour choisir une icone"]..">", 0, 1, 0);
									GameTooltip:Show();
								end);
	MainSettingsGuide_UIFrame.selectIcon.interact:SetScript("OnLeave", WC_Lib.OnLeave);
	MainSettingsGuide_UIFrame.selectIcon.interact:SetScript("OnClick", WCCreator_Lib.ToggleShowListIconSelector);
	MainSettingsGuide_UIFrame.selectIcon.interact:SetHighlightTexture("Interface/Buttons/ButtonHilight-Square");
	MainSettingsGuide_UIFrame.selectIcon.interact:SetBackdrop({
		bgFile = "Interface\\ICONS\\inv_misc_questionmark",
		insets = { left = 3, right = 2, top = 3, bottom = 2 }});
	MainSettingsGuide_UIFrame.selectIcon:SetPoint("CENTER", MainSettingsGuide_UIFrame.title3, "CENTER", -120, -65);
	
	-- ===== PARTIE INFO CLASS =====
	MainSettingsGuide_UIFrame.title4 = WCCreator_Lib.CreateTitle(core.L["Classes"], child);
	MainSettingsGuide_UIFrame.title4:SetPoint("TOP", MainSettingsGuide_UIFrame.title3, "BOTTOM", 0, -90);
	MainSettingsGuide_UIFrame.chbx_ClassAll = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_ClassAll, child);
	MainSettingsGuide_UIFrame.chbx_ClassAll:SetPoint("TOP", MainSettingsGuide_UIFrame.title4, "BOTTOM", -250, -10);
	MainSettingsGuide_UIFrame.chbx_Class1 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class1, child);
	MainSettingsGuide_UIFrame.chbx_Class1:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_ClassAll, "RIGHT", 60, 0);
	MainSettingsGuide_UIFrame.chbx_Class2 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class2, child);
	MainSettingsGuide_UIFrame.chbx_Class2:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_Class1, "RIGHT", 65, 0);
	MainSettingsGuide_UIFrame.chbx_Class3 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class3, child);
	MainSettingsGuide_UIFrame.chbx_Class3:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_Class2, "RIGHT", 60, 0);
	MainSettingsGuide_UIFrame.chbx_Class4 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class4, child);
	MainSettingsGuide_UIFrame.chbx_Class4:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_Class3, "RIGHT", 70, 0);
	MainSettingsGuide_UIFrame.chbx_Class5 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class5, child);
	MainSettingsGuide_UIFrame.chbx_Class5:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_Class4, "RIGHT", 52, 0);
	MainSettingsGuide_UIFrame.chbx_Class6 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class6, child);
	MainSettingsGuide_UIFrame.chbx_Class6:SetPoint("TOP", MainSettingsGuide_UIFrame.chbx_ClassAll, "BOTTOM", 0, -10);
	MainSettingsGuide_UIFrame.chbx_Class7 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class7, child);
	MainSettingsGuide_UIFrame.chbx_Class7:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_Class6, "RIGHT", 140, 0);
	MainSettingsGuide_UIFrame.chbx_Class8 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class8, child);
	MainSettingsGuide_UIFrame.chbx_Class8:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_Class7, "RIGHT", 65, 0);
	MainSettingsGuide_UIFrame.chbx_Class9 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class9, child);
	MainSettingsGuide_UIFrame.chbx_Class9:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_Class8, "RIGHT", 50, 0);
	MainSettingsGuide_UIFrame.chbx_Class10 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class10, child);
	MainSettingsGuide_UIFrame.chbx_Class10:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_Class9, "RIGHT", 80, 0);
	MainSettingsGuide_UIFrame.chbx_Class11 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class11, child);
	MainSettingsGuide_UIFrame.chbx_Class11:SetPoint("TOP", MainSettingsGuide_UIFrame.chbx_Class6, "BOTTOM", 0, -10);
	MainSettingsGuide_UIFrame.chbx_Class12 = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Class12, child);
	MainSettingsGuide_UIFrame.chbx_Class12:SetPoint("LEFT", MainSettingsGuide_UIFrame.chbx_Class11, "RIGHT", 60, 0);
	
	-- ===== PARTIE INFO SUPPLEMENTAIRE =====
	MainSettingsGuide_UIFrame.title5 = WCCreator_Lib.CreateTitle(core.L["Informations supplémentaires"], child);
	MainSettingsGuide_UIFrame.title5:SetPoint("TOP", MainSettingsGuide_UIFrame.title4, "BOTTOM", 0, -130);
	MainSettingsGuide_UIFrame.ddm_Faction = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Faction, child);
	MainSettingsGuide_UIFrame.ddm_Faction:SetPoint("TOP", MainSettingsGuide_UIFrame.title5, "BOTTOM", -115, -15);
	MainSettingsGuide_UIFrame.ddm_Expansion = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Expansion, child);
	MainSettingsGuide_UIFrame.ddm_Expansion:SetPoint("TOP", MainSettingsGuide_UIFrame.title5, "BOTTOM", 115, -15);
	MainSettingsGuide_UIFrame.ddm_Langage = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Langage, child);
	MainSettingsGuide_UIFrame.ddm_Langage:SetPoint("TOPRIGHT", MainSettingsGuide_UIFrame.ddm_Expansion, "BOTTOMRIGHT", 0, -15);
	MainSettingsGuide_UIFrame.ddm_Difficulty = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.MS_Difficulty, child);
	MainSettingsGuide_UIFrame.ddm_Difficulty:SetPoint("TOPLEFT", MainSettingsGuide_UIFrame.ddm_Faction, "BOTTOMLEFT", 0, -15);

	local dummyFrame = CreateFrame("Frame", nil, child);
	dummyFrame:SetSize(1, 85);
	dummyFrame:SetPoint("TOP", MainSettingsGuide_UIFrame.ddm_Difficulty, "BOTTOM");

	--- ===== PARTIE PREVIEW =====
	MainSettingsGuide_UIFrame.preview = CreatePreview(MainSettingsGuide_UIFrame);
	MainSettingsGuide_UIFrame.preview:SetPoint("BOTTOM", MainSettingsGuide_UIFrame, "BOTTOM", 0, 0);
	
	MainSettingsGuide_UIFrame:Hide();
	return MainSettingsGuide_UIFrame;
end

function MainSettingsGuide_UI:Fill(currentGuide)
	local MS_value = WCCreator_Lib.structures.MainSettings_value;
	if (currentGuide ~= nil) then
		MS_value.idGuide     = currentGuide.idGuide;
		MS_value.category    = currentGuide.category;
		MS_value.iconID      = currentGuide.icon;
		MS_value.name        = currentGuide["info"][1];
		MS_value.isCollected = currentGuide["info"][2];
		MS_value.description = currentGuide["info"][3];
		MS_value.location    = currentGuide["info"][4];
		MS_value.id          = currentGuide.id;
		MS_value.faction     = currentGuide.faction;
		MS_value.difficulty  = currentGuide.difficulty;
		MS_value.expansion   = currentGuide.expansion;
		MS_value.displayID   = currentGuide.Model.id;
		MS_value.modID       = currentGuide.Model.modID;
		MS_value.bOnPlayer   = currentGuide.Model.bOnPlayer;
		MS_value.av_settings = currentGuide.av_settings;
		MS_value.lang        = currentGuide.lang;
		for i = 1, #MS_value.class do
			MS_value.class[i] = false;
		end
		for j = 1, #currentGuide.class do
			MS_value.class[currentGuide.class[j]] = true;
		end
	else
		MS_value.idGuide     = "";
		MS_value.category    = "hf";
		MS_value.iconID      = 134400;
		MS_value.name        = core.L["Nouveau guide"];
		MS_value.isCollected = false;
		MS_value.description = "";
		MS_value.location    = "";
		MS_value.id          = "";
		MS_value.faction     = 3;
		MS_value.difficulty  = 1;
		MS_value.expansion   = "";
		MS_value.displayID   = 0;
		MS_value.modID       = 0;
		MS_value.bOnPlayer   = false;
		MS_value.av_settings = {version = 1, createBy = "", lastModified = ""};
		MS_value.lang        = { GetLocalNumberByLocalID() };
		MS_value.class       = {true, true, true, true, true, true, true, true, true, true, true, true};
		WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdAchiev"   , true);
		WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdMounts"   , true);
		WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdPets"     , true);
		WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdTransmogs", true);
	end
	MainSettingsGuide_UIFrame.Texttitle:SetText(MS_value.name);
	if (MS_value.category == "hf") then
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_MS_Category"], "|cFFF5CC00"..core.L["Catégorie"]..core.L["2points"].."|r "..core.L["Hauts-faits"]);
		if (MS_value.id ~= "" and MS_value.id ~= nil) then
			WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdAchiev", false);
			UIDropDownMenu_DisableDropDown(_G["WCC_dropdownmenu_MS_Category"]) 
		else
			WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdAchiev", true);
			UIDropDownMenu_EnableDropDown(_G["WCC_dropdownmenu_MS_Category"]) 
		end
		_G["WCC_textbox_MS_IdAchiev"]:SetText(MS_value.id);
		_G["WCC_textbox_MS_IdAchievValid"]:SetText(MS_value.id);
		_G["WCC_textbox_MS_IdMounts"]:Hide();
		_G["WCC_textbox_MS_IdMountsValid"]:Hide();
		_G["WCC_textbox_MS_IdPets"]:Hide();
		_G["WCC_textbox_MS_IdPetsValid"]:Hide();
		_G["WCC_textbox_MS_IdTransmogs"]:Hide();
		_G["WCC_textbox_MS_IdTransmogsValid"]:Hide();
		_G["WCC_textbox_MS_ModID"]:Hide();
		WCCreator_Lib.TextBoxSetDisable(_G["WCC_textbox_MS_DisplayID"]);
		_G["WCC_textbox_MS_DisplayID"]:SetText("");
		_G["WCC_textbox_MS_DisplayID"]:Show();
		_G["WCC_textbox_MS_DisplayIDBtn"]:Disable();
		_G["WCC_MS_PreviewCategory"]:SetBackdrop({bgFile = "Interface/AddOns/WoWChallengerCREATOR/images/hf_category"});
		_G["WCC_MS_PreviewCategory"].cat = core.L["Hauts-faits"];
	elseif (MS_value.category == "mounts") then
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_MS_Category"], "|cFFF5CC00"..core.L["Catégorie"]..core.L["2points"].."|r "..core.L["Mounts"]);
		if (MS_value.id ~= "" and MS_value.id ~= nil) then
			WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdMounts", false);
			UIDropDownMenu_DisableDropDown(_G["WCC_dropdownmenu_MS_Category"]) 
		else
			WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdMounts", true);
			UIDropDownMenu_EnableDropDown(_G["WCC_dropdownmenu_MS_Category"]) 
		end
		_G["WCC_textbox_MS_IdMounts"]:SetText(MS_value.id);
		_G["WCC_textbox_MS_IdMountsValid"]:SetText(MS_value.id);
		_G["WCC_textbox_MS_IdAchiev"]:Hide();
		_G["WCC_textbox_MS_IdAchievValid"]:Hide();
		_G["WCC_textbox_MS_IdPets"]:Hide();
		_G["WCC_textbox_MS_IdPetsValid"]:Hide();
		_G["WCC_textbox_MS_IdTransmogs"]:Hide();
		_G["WCC_textbox_MS_IdTransmogsValid"]:Hide();
		_G["WCC_textbox_MS_DisplayID"]:SetText(MS_value.displayID);
		_G["WCC_textbox_MS_DisplayID"]:Show();
		WCCreator_Lib.TextBoxSetEnable(_G["WCC_textbox_MS_DisplayID"]);
		_G["WCC_textbox_MS_DisplayIDBtn"]:Enable();
		_G["WCC_textbox_MS_ModID"]:Hide();
		_G["WCC_MS_PreviewCategory"]:SetBackdrop({bgFile = "Interface/AddOns/WoWChallengerCREATOR/images/mount_category"});
		_G["WCC_MS_PreviewCategory"].cat = core.L["Mounts"];
	elseif (MS_value.category == "pets") then
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_MS_Category"], "|cFFF5CC00"..core.L["Catégorie"]..core.L["2points"].."|r "..core.L["Pets"]);
		if (MS_value.id ~= "" and MS_value.id ~= nil) then
			WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdPets", false);
			UIDropDownMenu_DisableDropDown(_G["WCC_dropdownmenu_MS_Category"]) 
		else
			WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdPets", true);
			UIDropDownMenu_EnableDropDown(_G["WCC_dropdownmenu_MS_Category"]) 
		end
		_G["WCC_textbox_MS_IdPets"]:SetText(MS_value.id);
		_G["WCC_textbox_MS_IdPetsValid"]:SetText(MS_value.id);
		_G["WCC_textbox_MS_IdAchiev"]:Hide();
		_G["WCC_textbox_MS_IdAchievValid"]:Hide();
		_G["WCC_textbox_MS_IdMounts"]:Hide();
		_G["WCC_textbox_MS_IdMountsValid"]:Hide();
		_G["WCC_textbox_MS_IdTransmogs"]:Hide();
		_G["WCC_textbox_MS_IdTransmogsValid"]:Hide();
		_G["WCC_textbox_MS_ModID"]:Hide();
		_G["WCC_textbox_MS_DisplayID"]:SetText(MS_value.displayID);
		_G["WCC_textbox_MS_DisplayID"]:Show();
		_G["WCC_textbox_MS_DisplayIDBtn"]:Enable();
		WCCreator_Lib.TextBoxSetEnable(_G["WCC_textbox_MS_DisplayID"]);
		_G["WCC_MS_PreviewCategory"]:SetBackdrop({bgFile = "Interface/AddOns/WoWChallengerCREATOR/images/pet_category"});
		_G["WCC_MS_PreviewCategory"].cat = core.L["Pets"];
	elseif (MS_value.category == "transmogs") then
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_MS_Category"], "|cFFF5CC00"..core.L["Catégorie"]..core.L["2points"].."|r "..core.L["Transmogs"]);
		if (MS_value.id ~= "" and MS_value.id ~= nil) then
			WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdTransmogs", false);
			UIDropDownMenu_DisableDropDown(_G["WCC_dropdownmenu_MS_Category"]) 
		else
			WCCreator_Lib.SwitchValidEdit("WCC_textbox_MS_IdTransmogs", true);
			UIDropDownMenu_EnableDropDown(_G["WCC_dropdownmenu_MS_Category"]) 
		end
		_G["WCC_textbox_MS_IdTransmogs"]:SetText(MS_value.id);
		_G["WCC_textbox_MS_IdTransmogsValid"]:SetText(MS_value.id);
		_G["WCC_textbox_MS_IdAchiev"]:Hide();
		_G["WCC_textbox_MS_IdAchievValid"]:Hide();
		_G["WCC_textbox_MS_IdMounts"]:Hide();
		_G["WCC_textbox_MS_IdMountsValid"]:Hide();
		_G["WCC_textbox_MS_IdPets"]:Hide();
		_G["WCC_textbox_MS_IdPetsValid"]:Hide();
		_G["WCC_textbox_MS_DisplayID"]:Hide();
		_G["WCC_textbox_MS_DisplayIDBtn"]:Enable();
		_G["WCC_MS_PreviewCategory"]:SetBackdrop({bgFile = "Interface/AddOns/WoWChallengerCREATOR/images/transmog_category"});
		_G["WCC_MS_PreviewCategory"].cat = core.L["Transmogs"];
		_G["WCC_textbox_MS_ModID"]:SetText(MS_value.modID);
		_G["WCC_textbox_MS_ModID"]:Show();
	end
	_G["WCC_textbox_MS_Name"]:SetText(MS_value.name);
	_G["WCC_multiline_MS_Desc"]:SetText(MS_value.description);
	_G["WCC_multiline_MS_Location"]:SetText(MS_value.location);
	_G["WCC_MS_GuideIconInteract"]:SetBackdrop({bgFile = MS_value.iconID, insets = { left = 3, right = 2, top = 3, bottom = 2 }});
	-- CLASSES
	local allclass = true;
	for k = 1, #MS_value.class do
		_G["WCC_checkbox_MS_Class"..k]:Enable();
		if (MS_value.class[k] == true) then
			_G["WCC_checkbox_MS_Class"..k]:SetChecked(true);
		else
			_G["WCC_checkbox_MS_Class"..k]:SetChecked(false);
			allclass = false;
		end
	end
	if (allclass == true) then
		for l = 1, #MS_value.class do
			_G["WCC_checkbox_MS_Class"..l]:Disable();
		end
	end
	--- INFO SUPP
	UIDropDownMenu_SetText(_G["WCC_dropdownmenu_MS_Faction"], "|cFFF5CC00"..core.L["Faction"]..core.L["2points"].."|r " ..core.L["FactionList"][MS_value.faction]);
	UIDropDownMenu_SetText(_G["WCC_dropdownmenu_MS_Difficulty"], "|cFFF5CC00"..core.L["Difficulté"]..core.L["2points"].."|r " ..core.L["Difficult"][MS_value.difficulty]);
	if (MS_value.expansion == "") then
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_MS_Expansion"], "|cFFF5CC00"..core.L["Expansion"]..core.L["2points"].."|r "..core.L["Non précisé"]);
	else
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_MS_Expansion"], "|cFFF5CC00"..core.L["Expansion"]..core.L["2points"].."|r " ..MS_value.expansion);
	end
	UIDropDownMenu_SetText(_G["WCC_dropdownmenu_MS_Langage"], "|cFFF5CC00"..core.L["Langue"]..core.L["2points"].."|r " ..core.L["LangSTR"][MS_value.lang[1]]);
	--- PREVIEW
	_G["WCC_MS_PreviewIcon"]:SetBackdrop({bgFile = MS_value.iconID});
	_G["WCC_MS_PreviewText"]:SetText(MS_value.name);
	if (MS_value.isCollected == true) then
		_G["WCC_MS_PreviewText"]:SetFontObject("GameFontGreen");
	else
		_G["WCC_MS_PreviewText"]:SetFontObject("GameFontNormal");
	end
	if (MS_value.faction == 2) then
		_G["WCC_MS_PreviewFaction"]:SetBackdrop({bgFile = "Interface/AddOns/WoWChallenger/images/mounts/button_bg_horde"});
	elseif (MS_value.faction == 1) then
		_G["WCC_MS_PreviewFaction"]:SetBackdrop({bgFile = "Interface/AddOns/WoWChallenger/images/mounts/button_bg_alliance"});			
	else
		_G["WCC_MS_PreviewFaction"]:SetBackdrop({bgFile = ""});			
	end
	if (MS_value.idGuide == "") then
		_G["WCC_MS_PreviewBtnSave"]:SetText(core.L["Créer"]);
	else
		_G["WCC_MS_PreviewBtnSave"]:SetText(core.L["Sauvegarder"]);
	end
end

function WCCreator_Lib.ShowMainParamGuide(self)
	local bJustHide = false;
	local menuParamGuide = MainSettingsGuide_UIFrame or MainSettingsGuide_UI:Create();
	if (self.idGuide ~= nil) then
		local currentGuide = WC_Lib.GetGuideByID(self.idGuide, "WCC");
		MainSettingsGuide_UI:Fill(currentGuide);
		bJustHide = true;
	else
		MainSettingsGuide_UI:Fill(nil);
	end
	if _G["WCC_BasicFrames"] then _G["WCC_BasicFrames"]:Hide(); end
	PlaySound("679", "sfx");
	menuParamGuide:Show();
end
------ END MainSettingsGuide_UI ------

------ CONFIG ADDON ------
local WCC_registered = false;
local function WCC_CreateAddonConfig()
	local config = CreateFrame( "Frame", "WoWChallengerCreatorConfig", InterfaceOptionsFramePanelContainer);
	config.name = "WoW Challenger Creator";
	 
	 
	local title = "WoW Challenger Creator v"..GetAddOnMetadata("WoWChallengerCreator", "Version")
	local titleFrame = config:CreateFontString(nil, "OVERLAY", "GameFontNormalLarge");
	titleFrame:SetText(title);
	titleFrame:SetPoint("TOPLEFT", config, "TOPLEFT", 15, -17);
	local desc = GetAddOnMetadata("WoWChallengerCreator", "Notes")
	local descFrame = config:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall");
	descFrame:SetText(desc);
	descFrame:SetPoint("TOPLEFT", titleFrame, "BOTTOMLEFT", 0, -7);
	
	local chbx_ActivateID = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.Config_ActivateID, config);
	chbx_ActivateID:SetPoint("TOPLEFT", descFrame, "BOTTOMLEFT", 0, -20);
	_G["WCC_checkbox_Config_ActivateID"]:SetChecked(TooltipIDShow);
	
	InterfaceOptions_AddCategory(config);
end
local WCC_IOF = CreateFrame("Frame", nil, InterfaceOptionsFrame)
WCC_IOF:SetScript("OnShow", function(self)
	if not WCC_registered then
		WCC_CreateAddonConfig();
		WCC_registered = true;
	end
	self:SetScript("OnShow", nil)
end)
------ END CONFIG ADDON ------

local function CreateWCC_UI()
	WCC_UI = CreateFrame("Frame", "WoWChallengerCreatorFrame", WC_Draggable, "PortraitFrameTemplateNoCloseButton");
	WCC_UI:SetSize(800,475);
	WCC_UI:SetScript("OnHide", function(self)
		if (_G["WCC_MenuSettingsTaskFrame"]) then _G["WCC_MenuSettingsTaskFrame"]:Hide(); end
		if (_G["WCC_MenuSettingsStepFrame"]) then _G["WCC_MenuSettingsStepFrame"]:Hide(); end
		if (_G["WCC_MenuSettingsRensFrame"]) then _G["WCC_MenuSettingsRensFrame"]:Hide(); end
		if (_G["WC_PopupExportGuide"])       then _G["WC_PopupExportGuide"]      :Hide(); end
	end);
	WCC_UI:SetScript("OnKeyDown", function(self, key)
		if (key == "ESCAPE" and WCC_UI:IsShown()) then
			PlaySound("680", "sfx");
			self:GetParent():Hide();
		end
	end);
	WCC_UI:SetPropagateKeyboardInput(true)

	WCC_UI.title = WCC_UI:CreateFontString(nil, "OVERLAY", "GameFontNormal");
	WCC_UI.title:SetText("WoW Challenger Creator");
	WCC_UI.title:SetPoint("CENTER", WCC_UI.TitleBg, "CENTER");

	WCC_UI.close = CreateFrame("Button", "BtnCloseWCCreator", WCC_UI, "UIPanelCloseButton");
	WCC_UI.close:SetSize(32, 30);
	WCC_UI.close:SetPoint("TOPRIGHT", WCC_UI, "TOPRIGHT", 6, 4);
	WCC_UI.close:SetScript("OnClick", function(self)
		WC_Draggable:Hide();
		PlaySound("680", "sfx");
	end);
	
	WCC_UI.portrait = CreateFrame("Frame", "PortraitFrame", WCC_UI, BackdropTemplateMixin and "BackdropTemplate");
	WCC_UI.portrait:SetSize(60,60);
	WCC_UI.portrait:SetFrameLevel(15);
	WCC_UI.portrait:SetPoint("TOPLEFT", WCC_UI, "TOPLEFT", -5, 7);
	WCC_UI.portrait:SetBackdrop({bgFile = "Interface/AddOns/WoWChallengerCreator/images/icon_wccreator",
												tile = false,
												insets = { left = 0, right = 0, top = 0, bottom = 0 }
												});

	local BtnInactiveWCCreator = CreateFrame("Button", "BtnInactiveWCCreator", WCC_UI, "UIPanelButtonTemplate");
	BtnInactiveWCCreator:SetSize(110, 26);
	BtnInactiveWCCreator:SetText(core.L["Quitter Creator"]);
	BtnInactiveWCCreator:SetPoint("LEFT", WCC_UI.TitleBg, "LEFT", 56, 0);
	BtnInactiveWCCreator:SetScript("OnLeave", WC_Lib.OnLeave);
	BtnInactiveWCCreator:SetScript("OnEnter", WCCreator_Lib.tooltip.tooltip_WCCreatorOff);
	BtnInactiveWCCreator:SetScript("OnClick", function(self)
		WCCreator_Lib.OnClick_ShowWCC();		
		WC_Lib.SetShowHideToModel("show");
	end);
	
	------- BOUTON REJOINDRE -------
	local BtnJoin = CreateFrame("Button", "WCC_BtnJoin", WCC_UI, "UIPanelButtonTemplate");
	BtnJoin:SetSize(110, 26);
	BtnJoin:SetText(core.L["Join"]);
	BtnJoin:SetPoint("RIGHT", WCC_UI.TitleBg, "RIGHT", 2, 0);
	BtnJoin.contextMenu = CreateFrame("Frame", nil, btn, "UIDropDownMenuTemplate");
	BtnJoin:SetScript("OnClick", function(self)
		EasyMenu(WCCreator_Lib.structures.WCCJoinMenu.info, BtnJoin.contextMenu, BtnJoin, 0 , 0, "MENU")
	end);
	------- END BOUTON REJOINDRE -------
	
	----- GUIDES LIST -----
	local GuidesList = CreateFrame("Frame", "WCC_GuidesList", WCC_UI, BackdropTemplateMixin and "BackdropTemplate");
	GuidesList:SetSize(245,450);
	GuidesList:SetPoint("LEFT", WCC_UI, "LEFT", 1, -10);
	GuidesList:SetBackdrop({bgFile = "Interface/FrameGeneral/UI-Background-Marble",
						edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
						tile = false, edgeSize = 16, 
						insets = { left = 0, right = 3, top = 0, bottom = 0 }});
	local HeaderGuidesList = WC_Lib.CreateHeaderGuideList(GuidesList, "WCC");

	
	GuidesList.ScrollFrame = CreateFrame("ScrollFrame", "WCC_GuidesListScroll", GuidesList, "UIPanelScrollFrameTemplate");
	GuidesList.ScrollFrame:SetPoint("TOPLEFT", GuidesList, "TOPLEFT", 0, -80);
	GuidesList.ScrollFrame:SetPoint("BOTTOMRIGHT", GuidesList, "BOTTOMRIGHT", 0, 0);
	GuidesList.ScrollFrame:SetClipsChildren(true);
	GuidesList.ScrollFrame.ScrollBar:ClearAllPoints();
	GuidesList.ScrollFrame.ScrollBar:SetPoint("TOPRIGHT", GuidesList.ScrollFrame, "TOPRIGHT", -4, -20);
	GuidesList.ScrollFrame.ScrollBar:SetPoint("BOTTOMRIGHT", GuidesList.ScrollFrame, "BOTTOMRIGHT", -4, 20);
	local child = CreateFrame("Frame", "WCC_GuidesListScrollChild", GuidesList.ScrollFrame);
	child:SetSize(GuidesList:GetWidth(), GuidesList:GetWidth());

							
	GuidesList.ScrollFrame:SetScrollChild(child);
	GuidesList.ScrollFrame:SetScript("OnMouseWheel", WC_Lib.ScrollFrame_OnMouseWheel);
	
	----- BUTTON CREATE GUIDE -----
	local BtnCreateGuide = CreateFrame("Button", "BtnCreateGuide", GuidesList, "UIPanelButtonTemplate");
	BtnCreateGuide:SetSize(GuidesList:GetWidth()-5, 33);
	BtnCreateGuide:SetText(core.L["Nouveau guide"]);
	BtnCreateGuide.addon = "WCC";
	BtnCreateGuide:SetPoint("TOP", HeaderGuidesList, "BOTTOM", 0, 10);
	BtnCreateGuide:SetFrameLevel(HeaderGuidesList:GetFrameLevel() + 1);
	BtnCreateGuide:SetScript("OnClick", WCCreator_Lib.ShowMainParamGuide);
	
	WC_Lib.RefreshListCollections("WCC");
	WCC_UI:Hide();

	return WCC_UI;
end
core.wccreator.CreateWCC_UI = CreateWCC_UI;

if (BtnActiveWCCreator ~= nil) then
	BtnActiveWCCreator:SetScript("OnClick", WCCreator_Lib.OnClick_ShowWCC);
	BtnActiveWCCreator:SetScript("OnEnter", WCCreator_Lib.tooltip.tooltip_WCCreatorOn);
end