local _, core = ...;

------ CREATE MULTILINE ------
function WCCreator_Lib.CreateMultiline(settings, parent)
	local mainFrame = CreateFrame("Button", nil, parent, BackdropTemplateMixin and "BackdropTemplate");
	mainFrame:SetSize(settings.width+25, settings.height);
	mainFrame:SetScript("OnClick", function(self) self.multiline:SetFocus() end);
	mainFrame:SetBackdrop({bgFile = [[Interface\GLUES\COMMON\Glue-Tooltip-Background]],
							edgeFile = [[Interface\GLUES\COMMON\TextPanel-Border]],
							edgeSize = 14,
							insets = {left = 5, right = 1, top = 1, bottom = 4},
												});

	local scroll = CreateFrame("ScrollFrame", nil, mainFrame, "UIPanelScrollFrameTemplate");
	scroll:SetSize(mainFrame:GetWidth()-20, mainFrame:GetHeight()-15);
	scroll:SetPoint("CENTER", mainFrame, "CENTER", -4, 0);
	
	mainFrame.multiline = CreateFrame("EditBox",  "WCC_"..settings.frameType.."_"..settings.frameTitle, mainFrame);
	mainFrame.multiline:SetMultiLine(true);
	mainFrame.multiline:SetAutoFocus(false);
	mainFrame.multiline:SetFontObject("GameFontWhite");
	mainFrame.multiline:SetWidth(settings.width);
	if (settings.event ~= nil) then
		for i = 1, #settings.event do
			mainFrame.multiline:SetScript(settings.event[i].name, settings.event[i].func);
		end
	end
	
	scroll:SetScrollChild(mainFrame.multiline);

	mainFrame.title = mainFrame:CreateFontString("WCC_"..settings.frameType.."_"..settings.frameTitle.."Title", "OVERLAY", mainFrame);
	mainFrame.title:SetFontObject("GameFontNormal");
	mainFrame.title:SetText(settings.title);
	mainFrame.title:SetPoint("BOTTOMLEFT", mainFrame, "TOPLEFT", 3, 0);
	
	if (settings.options == nil or settings.options == true) then
		-- Bouton Ajouter un nom d'objet
		mainFrame.addItemBtn = CreateFrame("Button", nil, mainFrame, "UIPanelButtonTemplate");
		mainFrame.addItemBtn:SetSize(20, 15);
		mainFrame.addItemBtn:SetText("+");
		mainFrame.addItemBtn:SetPoint("BOTTOMRIGHT", mainFrame, "TOPRIGHT", 0, 0);
		mainFrame.addItemBtn:SetScript("OnLeave", WCCreator_Lib.tooltip.OnLeave);
		mainFrame.addItemBtn:SetScript("OnEnter", function(self, motion)
												GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT", 0, 0);
												GameTooltip:AddLine(core.L["Nom d'objet"]);
												GameTooltip:AddLine(core.L["Ajouter un nom d'objet avec son icône et sa couleur de rareté"], 1, 1, 1, true);
												GameTooltip:Show();
												end);
		mainFrame.addItemBtn:SetScript("OnClick", function(self)
													local idItem = mainFrame.tb_addItem:GetText();
													if (not mainFrame.tb_addItem:IsShown()) then
														mainFrame.tb_addItem:Show();
														mainFrame.questColorBtn:Hide();
													elseif (idItem == "") then
														mainFrame.tb_addItem:Hide();
														mainFrame.questColorBtn:Show();
													else
														mainFrame.tb_addItem:Disable();
														local item = Item:CreateFromItemID(tonumber(idItem));
														local isEmpty = item:IsItemEmpty();
														if (isEmpty == false) then
															item:ContinueOnItemLoad(function()
																local getInfoItem = {GetItemInfo(tonumber(idItem))};
																local itemInfo = {};
																itemInfo[1] = getInfoItem[1];
																itemInfo[2] = getInfoItem[2];
																itemInfo[3] = getInfoItem[3];
																itemInfo[4] = getInfoItem[10];
																mainFrame.multiline:Insert(WC_Lib.nameItemInColor(itemInfo, 1));
																mainFrame.tb_addItem:SetText("");
																mainFrame.tb_addItem:Hide();
																mainFrame.questColorBtn:Show();
																mainFrame.tb_addItem:Enable();
															end)
														else
															UIErrorsFrame:AddMessage(core.L["ErrorNoFindID"], 1, 0, 0);
															PlaySound("47355", "sfx", true);
															mainFrame.tb_addItem:Enable();
														end
													end
												end);

		-- Bouton texte en couleur de quête
		mainFrame.questColorBtn = CreateFrame("Button", nil, mainFrame, "UIPanelButtonTemplate");
		mainFrame.questColorBtn:SetSize(20, 15);
		mainFrame.questColorBtn:SetText("!");
		mainFrame.questColorBtn:SetPoint("RIGHT", mainFrame.addItemBtn, "LEFT", 0, 0);
		mainFrame.questColorBtn:SetScript("OnLeave", WCCreator_Lib.tooltip.OnLeave);
		mainFrame.questColorBtn:SetScript("OnEnter", function(self, motion)
												GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT", 0, 0);
												GameTooltip:AddLine(core.L["Couleur quête"]);
												GameTooltip:AddLine(core.L["Mettre en couleur de quête les mots sélectionnés"], 1, 1, 1, true);
												GameTooltip:Show();
												end);
		mainFrame.questColorBtn:SetScript("OnClick", function(self)
													local text, cursor = mainFrame.multiline:GetText(), mainFrame.multiline:GetCursorPosition();
													mainFrame.multiline:Insert("");
													local textNew, cursorNew = mainFrame.multiline:GetText(), mainFrame.multiline:GetCursorPosition();
													local Start, End = cursorNew, #text - ( #textNew - cursorNew );
													mainFrame.multiline:Insert("|cFFF5CC00"..text:sub(Start + 1, End).."|r");
												end);
		
		-- Textbox Ajouter un nom d'objet
		mainFrame.tb_addItem = CreateFrame("EditBox",  nil, mainFrame, "InputBoxTemplate");
		mainFrame.tb_addItem:SetSize(100, 15);
		mainFrame.tb_addItem:SetPoint("RIGHT", mainFrame.addItemBtn, "LEFT", 0, 0);
		mainFrame.tb_addItem:SetFontObject("GameFontWhite");
		mainFrame.tb_addItem:SetAutoFocus(false);
		mainFrame.tb_addItem:SetNumeric(true);
		mainFrame.tb_addItem:SetScript("OnEditFocusLost", WCCreator_Lib.tooltip.OnLeaveFieldHelp);
		mainFrame.tb_addItem:SetScript("OnEditFocusGained", WCCreator_Lib.tooltip.tooltip_ShowFieldHelp);
		mainFrame.tb_addItem:Hide();
		
		mainFrame.tb_addItem.helpIcon = CreateFrame("Frame", nil, mainFrame.tb_addItem, "UIPanelInfoButton");
		mainFrame.tb_addItem.helpIcon.title = settings.title;
		mainFrame.tb_addItem.helpIcon.desc = settings.desc;
		mainFrame.tb_addItem.helpIcon:SetSize(16, 16);
		mainFrame.tb_addItem.helpIcon:SetPoint("RIGHT", mainFrame.tb_addItem, "RIGHT", -2, 0);
		mainFrame.tb_addItem.helpIcon:Hide();
		mainFrame.tb_addItem.helpIcon:SetScript("OnLeave", WCCreator_Lib.tooltip.OnLeave);
		mainFrame.tb_addItem.helpIcon:SetScript("OnEnter", function(self, motion)
																GameTooltip:SetOwner(self, "ANCHOR_TOPLEFT", 0, 0);
																GameTooltip:AddLine(core.L["ID Objet"]);
																GameTooltip:AddLine(core.L["Entrez l'ID de l'objet souhaité puis rappuyez sur le +"], 1, 1, 1, true);
																GameTooltip:Show();
															end);
	end
	return mainFrame;
end