local _, core = ...;
local ListIconSelector = nil;

local tooltip_iconSelector = function(self, motion)
	GameTooltip:SetOwner(self, "ANCHOR_TOP", 0, 0);
	GameTooltip:AddLine(self.title, 1, 1, 1);
	GameTooltip:AddLine("<Cliquer pour choisir une icône>", 0, 1, 0);
	GameTooltip:Show();
end

local tooltipOnIcon = function(self, motion)
	GameTooltip:SetOwner(_G["WCC_ListIconSelectorFrameIcon"], "ANCHOR_TOPLEFT", 0, 0);
	GameTooltip:AddLine(" ");
    GameTooltip:AddTexture(self.iconSelected..".blp", {width = 100,	height = 100});
	GameTooltip:AddLine(GetFileIDFromPath(self.iconSelected));
	GameTooltip:AddLine(self.iconSelected);
	GameTooltip:Show();
end
---------- END GAMETOOLTIP ----------


------ CREATE SELECTOR ICON ------
local arr_iconName = WCCreator_Lib.returnIconListName();
local currentPage = 0;
local MAX_ICONS_DISPLAYED = 56;
local maxPage = math.ceil(#arr_iconName/MAX_ICONS_DISPLAYED);

local function UpdateBgIcon()
	for i = 0, MAX_ICONS_DISPLAYED-1 do
		local path_icon = arr_iconName[(i+1)+(MAX_ICONS_DISPLAYED*currentPage)]
		if (path_icon ~= nil) then
			_G["WCC_ListIconSelectorFrameIcon"..i]:SetBackdrop({
				bgFile = "Interface\\ICONS\\"..path_icon,
				edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
				edgeSize = 8,
				insets = { left = 0, right = 0, top = 0, bottom = 0 }
			});
			_G["WCC_ListIconSelectorFrameIcon"..i].iconSelected =  "Interface\\ICONS\\"..arr_iconName[(i+1)+(MAX_ICONS_DISPLAYED*currentPage)];
			_G["WCC_ListIconSelectorFrameIcon"..i]:Show();
		else
			_G["WCC_ListIconSelectorFrameIcon"..i]:Hide();
		end
	end
end

local function ChangingPage(self)
	currentPage = currentPage + self.nbChangePage;
	local maxPageMinusOne = maxPage - 1;
	if (currentPage > maxPageMinusOne) then
		currentPage = maxPageMinusOne;
	elseif (currentPage < 0) then
		currentPage = 0;
	end
	_G["WCC_textbox_ListIcon_NbPage"]:SetText((currentPage+1));
	UpdateBgIcon();
	PlaySound("605", "sfx", true);
end

local function ChangingPageByText(self)
	if (self:GetText() ~= nil and self:GetText() ~= "" and WCCreator_Lib.checkIfLetter(self:GetText()) == false) then
		currentPage = tonumber(self:GetText()) - 1;
		local maxPageMinusOne = maxPage - 1;
		if (currentPage > maxPageMinusOne) then
			currentPage = maxPageMinusOne;
		elseif (currentPage < 0) then
			currentPage = 0;
		end
		_G["WCC_textbox_ListIcon_NbPage"]:SetText((currentPage+1));
		UpdateBgIcon();
		PlaySound("605", "sfx", true);
	end
end

local function SearchByFileID(self)
	if (WCCreator_Lib.checkIfLetter(_G["WCC_textbox_ListIcon_FileID"]:GetText()) == false) then
		self.iconSelected = tonumber(_G["WCC_textbox_ListIcon_FileID"]:GetText());
		self.func(self);
	end
end

local function CreateListIconSelector(self)
	ListIconSelector = CreateFrame("Frame", "WCC_ListIconSelectorFrameIcon", UIParent, BackdropTemplateMixin and "BackdropTemplate");
	ListIconSelector:SetSize(350,375);
	ListIconSelector:SetFrameLevel(501);
	ListIconSelector:SetMovable(true);
	ListIconSelector:EnableMouse(true);
	ListIconSelector:RegisterForDrag("LeftButton");
	ListIconSelector:SetScript("OnDragStart", ListIconSelector.StartMoving);
	ListIconSelector:SetScript("OnDragStop", ListIconSelector.StopMovingOrSizing);
	ListIconSelector:SetPoint("CENTER", UIParent, "CENTER");
	ListIconSelector:SetBackdrop({bgFile = "Interface/AddOns/WoWChallenger/images/challenges/bg_step_challenge",
							edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
							edgeSize = 8,
							insets = { left = 0, right = 0, top = 0, bottom = 0 }});
	
	ListIconSelector.title = ListIconSelector:CreateFontString(nil, "OVERLAY", ListIconSelector);
	if GetLocale() == "ruRU" then
		ListIconSelector.title:SetFont("Interface\\AddOns\\WoWChallenger\\fonts\\FRIZQT__CYR.TTF", 18, "OUTLINE");
	else
		ListIconSelector.title:SetFont("Fonts\\FRIZQT__.TTF", 18, "OUTLINE");
	end
	ListIconSelector.title:SetText(core.L["Liste icones"]);
	ListIconSelector.title:SetPoint("TOP", ListIconSelector, "TOP", 0, -12);

	ListIconSelector.close = CreateFrame("Button", "BtnCloseWCC_ListIconSelectorFrameIcon", ListIconSelector, "UIPanelCloseButton");
	ListIconSelector.close:SetSize(32, 32);
	ListIconSelector.close:SetPoint("TOPRIGHT", ListIconSelector, "TOPRIGHT", -10, -5);
	ListIconSelector.close:SetScript("OnClick", function(self)
		ListIconSelector:Hide();
		PlaySound("21967", "sfx", true);
	end);
	
	ListIconSelector.listIcons = CreateFrame("Frame", nil, ListIconSelector, BackdropTemplateMixin and "BackdropTemplate");
	ListIconSelector.listIcons:SetSize(ListIconSelector:GetWidth(), ListIconSelector:GetHeight()-20);
	ListIconSelector.listIcons:SetPoint("TOPLEFT", ListIconSelector, "TOPLEFT", 10, -45);
	ListIconSelector.listIcons:SetBackdrop({
		bg = "Interface/AddOns/WoWChallenger/images/challenges/bg_step_challenge", 
		edgeSize = 8,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
	});
	
	for i = 0, 55 do
		local icon = CreateFrame("Button", "WCC_ListIconSelectorFrameIcon"..i, ListIconSelector.listIcons, BackdropTemplateMixin and "BackdropTemplate");
		icon:SetSize(40, 40);
		icon.iconSelected = "Interface\\ICONS\\"..arr_iconName[i+1];
		icon:SetScript("OnEnter", tooltipOnIcon);
		icon:SetScript("OnLeave", WCCreator_Lib.tooltip.OnLeave);
		icon:SetHighlightTexture("Interface/Buttons/ButtonHilight-Square");
		icon:SetBackdrop({bgFile = "Interface\\ICONS\\"..arr_iconName[i+1],
							edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
							edgeSize = 8,
							insets = { left = 0, right = 0, top = 0, bottom = 0 }});
		if (i == 0) then
			icon:SetPoint("TOPLEFT", ListIconSelector.listIcons, "TOPLEFT", 0, 0);
		elseif (i%8 == 0) then
			icon:SetPoint("TOP", _G["WCC_ListIconSelectorFrameIcon"..i - 8], "BOTTOM", 0, 0);
		else
			icon:SetPoint("LEFT", _G["WCC_ListIconSelectorFrameIcon"..i - 1], "RIGHT", 0, 0);
		end
	end
	
	
	ListIconSelector.SearchFileID = CreateFrame("EditBox",  "WCC_textbox_ListIcon_FileID", ListIconSelector, "InputBoxTemplate");
	ListIconSelector.SearchFileID:SetSize(75, 10);
	ListIconSelector.SearchFileID:SetFontObject("GameFontWhite");
	ListIconSelector.SearchFileID:SetText(core.L["ID Icon"]);
	ListIconSelector.SearchFileID:SetAutoFocus(false);
	ListIconSelector.SearchFileID.iconSelected = 0;
	ListIconSelector.SearchFileID:SetScript("OnEnterPressed", SearchByFileID);
	ListIconSelector.SearchFileID:SetPoint("BOTTOMLEFT", ListIconSelector, "BOTTOMLEFT", 10, 20);
	
	--- CHANGING PAGE ---
	ListIconSelector.NbPage = CreateFrame("EditBox",  "WCC_textbox_ListIcon_NbPage", ListIconSelector, "InputBoxTemplate");
	ListIconSelector.NbPage:SetSize(45, 10);
	ListIconSelector.NbPage:SetFontObject("GameFontWhite");
	ListIconSelector.NbPage:SetText("1");
	ListIconSelector.NbPage:SetAutoFocus(false);
	ListIconSelector.NbPage:SetScript("OnTextChanged", ChangingPageByText);
	ListIconSelector.NbPage:SetPoint("BOTTOM", ListIconSelector, "BOTTOM", -10, 20);
	
	ListIconSelector.btnPrev = CreateFrame("Button", nil, ListIconSelector, "UIPanelButtonTemplate");
	ListIconSelector.btnPrev:SetSize(40, 20);
	ListIconSelector.btnPrev:SetText("<<");
	ListIconSelector.btnPrev.nbChangePage = -1;
	ListIconSelector.btnPrev:SetPoint("RIGHT", ListIconSelector.NbPage, "LEFT", -10, 0);
	ListIconSelector.btnPrev:SetScript("OnClick", ChangingPage);
	
	ListIconSelector.btnNext = CreateFrame("Button", nil, ListIconSelector, "UIPanelButtonTemplate");
	ListIconSelector.btnNext:SetSize(40, 20);
	ListIconSelector.btnNext:SetText(">>");
	ListIconSelector.btnNext.nbChangePage = 1;
	ListIconSelector.btnNext:SetPoint("LEFT", ListIconSelector.NbPage, "RIGHT", 10, 0);
	ListIconSelector.btnNext:SetScript("OnClick", ChangingPage);
	
	ListIconSelector:Hide();
	return ListIconSelector;
end

function WCCreator_Lib.ToggleShowListIconSelector(self)
	if (self ~= nil) then
		local listIS = ListIconSelector or CreateListIconSelector(self);
		listIS.SearchFileID.func = nil;
		listIS.SearchFileID.func = self.func_iconSelect;
		for i = 0, 55 do
			_G["WCC_ListIconSelectorFrameIcon"..i]:SetScript("OnClick", self.func_iconSelect);
		end
		if (listIS:IsShown()) then
			listIS:Hide();
		elseif (not listIS:IsShown()) then
			listIS:Show();
			PlaySound("21966", "sfx", true);
		end
	else
		print("Impossible d'ouvrir le sélecteur d'icône.");
	end
end
