local _, core = ...;
local MenuSettingsTask;

local function CheckIfErrorExists()
	local settings     = WCCreator_Lib.structures.SettingsTask_value;
	local bOk          = true;
	local messageError = "";
	if (settings.category == "custom") then
		if (settings.title == "") then
			messageError = messageError.."- "..core.L["Titre"].." : |cffff0000"..core.L["Le champ est vide."].."|r\n";
			bOk = false;
		end
		if (settings.desc == "") then
			messageError = messageError.."- "..core.L["Description"].." : |cffff0000"..core.L["Le champ est vide."].."|r\n";
			bOk = false;
		end
	elseif (settings.category == "hf") then
		if (settings.idHF ~= "") then
			if (tonumber(settings.idHF) < 2147483647) then
				local _, title = GetAchievementInfo(tonumber(settings.idHF));
				if (title == nil) then
					messageError = messageError.."- "..core.L["ID Haut-fait"].." : |cffff0000"..core.L["Aucun résultat a été trouvé."].."|r\n";
					bOk = false;
				else
					settings.title = title;
				end
			else
				messageError = messageError.."- "..core.L["ID Haut-fait"].." : |cffff0000"..core.L["Nombre trop élevé."].." (<2147483647)|r\n";
				bOk = false;
			end
		else
			messageError = messageError.."- "..core.L["ID Haut-fait"].." : |cffff0000"..core.L["Le champ est vide."].."|r\n";
			bOk = false;
		end
	elseif (settings.category == "quest") then
		if (settings.idQuest ~= "") then
			if (tonumber(settings.idQuest) >= 2147483647) then
				messageError = messageError.."- "..core.L["ID Quest"].." : |cffff0000"..core.L["Nombre trop élevé."].." (<2147483647)|r\n";
				bOk = false;
			end
		else
			messageError = messageError.."- "..core.L["ID Quest"].." : |cffff0000"..core.L["Le champ est vide."].."|r\n";
			bOk = false;
		end
		if (settings.bForceQuest == true) then
			if (settings.title == "") then
				messageError = messageError.."- "..core.L["Titre"].." : |cffff0000"..core.L["Le champ est vide."].."|r\n";
				bOk = false;
			end
			if (settings.desc == "") then
				messageError = messageError.."- "..core.L["Description"].." : |cffff0000"..core.L["Le champ est vide."].."|r\n";
				bOk = false;
			end
		end
	elseif (settings.category == "need") then
		if (not MenuSettingsTask.ItemFrame.tb_IdItemValid:IsShown()) then
			messageError = messageError.."- "..core.L["ID Objet"].." : |cffff0000"..core.L["Champ non validé."].."|r\n";
			bOk = false;
		end
		if (tostring(settings.nbRequired) == "") then
			messageError = messageError.."- "..core.L["Nombre"].." : |cffff0000"..core.L["Le champ est vide."].."|r\n";
			bOk = false;
		elseif (tonumber(settings.nbRequired) > 999) then
			messageError = messageError.."- "..core.L["Nombre"].." : |cffff0000"..core.L["Nombre trop élevé."].." (<999)|r\n";
			bOk = false;
		end
		if (settings.obtentionType == "quest" and not MenuSettingsTask.ItemFrame.tb_Obtention_IdQuestValid:IsShown()) then
			messageError = messageError.."- "..core.L["ID Quest"].." : |cffff0000"..core.L["Champ non validé."].."|r\n";
			bOk = false;
		elseif (settings.obtentionType == "hf" and not MenuSettingsTask.ItemFrame.tb_Obtention_IdHFValid:IsShown()) then
			messageError = messageError.."- "..core.L["ID Haut-fait"].." : |cffff0000"..core.L["Champ non validé."].."|r\n";
			bOk = false;
		elseif (settings.obtentionType == "loot" and #settings.obtention_loot == 0) then
			messageError = messageError.."- "..core.L["DroppedBy"].." : |cffff0000"..core.L["Liste vide."].."|r\n";
			bOk = false;
		elseif (settings.obtentionType == "vendor" and #settings.obtention_vendor == 0) then
			messageError = messageError.."- "..core.L["SoldBy"].." : |cffff0000"..core.L["Liste vide."].."|r\n";
			bOk = false;
		elseif (settings.obtentionType == "create" and #settings.obtention_create == 0) then
			messageError = messageError.."- "..core.L["CreatedBy"].." : |cffff0000"..core.L["Liste vide."].."|r\n";
			bOk = false;
		end
		if (settings.validationType ~= "manual") then
			if (settings.validationId == "") then
				messageError = messageError.."- "..core.L["ID Validation"].." : |cffff0000"..core.L["Le champ est vide."].."|r\n";
				bOk = false;
			elseif (tonumber(settings.validationId) >= 2147483647) then
				messageError = messageError.."- "..core.L["ID Validation"].." : |cffff0000"..core.L["Nombre trop élevé."].." (<2147483647)|r\n";
				bOk = false;
			end
		end
	end
	return unpack({bOk, messageError});
end

local ShowListErrorEditTask = function(self, motion)
	local settings = WCCreator_Lib.structures.SettingsTask_value;
	local bOk, messageError = CheckIfErrorExists();
	if (bOk == false) then
		GameTooltip:SetOwner(self, "ANCHOR_TOP", 0, 0);
		GameTooltip:AddLine(core.L["Informations incorrectes"], 1, 1, 1);
		GameTooltip:AddLine(messageError);
		GameTooltip:Show();
	end
end

function WCCreator_Lib.SetSizeMenuSettingsTask()
	local settings = WCCreator_Lib.structures.SettingsTask_value;
	local height = 285;
	if (settings.category == "hf") then
		height = 200;
	elseif (settings.category == "quest") then
		if (settings.bForceQuest == true) then
			height = 380;
		else
			height = 200;
		end
	elseif (settings.category == "need") then
		height = 400;
		if (settings.obtentionType == "quest" or settings.obtentionType == "hf") then
			height = 465;
		elseif (settings.obtentionType ~= "none") then
			height = height + 40 + MenuSettingsTask.ItemFrame.fs_Obtention_desc:GetHeight();
			if (settings.obtentionType == "loot") then
				height = height + MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame:GetHeight();
				MenuSettingsTask.ItemFrame.subtitle3:SetPoint("TOP", MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame, "BOTTOM", -15, -10);
			elseif (settings.obtentionType == "vendor") then
				height = height + MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame:GetHeight();
				MenuSettingsTask.ItemFrame.subtitle3:SetPoint("TOP", MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame, "BOTTOM", -15, -10);
			elseif (settings.obtentionType == "create") then
				height = height + 50; -- profession bar
				height = height + MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame:GetHeight();
				MenuSettingsTask.ItemFrame.subtitle3:SetPoint("TOP", MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame, "BOTTOM", -15, -10);
			end
		end
		if (settings.validationType ~= "manual") then
			height = height + 40;
		end
	end
	MenuSettingsTask:SetSize(400, height);
end

function WCCreator_Lib.ShowForceQuest()
	local settings = WCCreator_Lib.structures.SettingsTask_value;
	if (settings.bForceQuest == true) then
		MenuSettingsTask.QuestFrame.NoDescMessage:Show();
		MenuSettingsTask.QuestFrame.tb_TitleForce:Show();
		MenuSettingsTask.QuestFrame.tb_TitleForce:SetText(settings.title or "");
		MenuSettingsTask.QuestFrame.multi_DescForce:Show();
		_G["WCC_multiline_ST_DescForce"]:SetText(settings.desc or "");
	else
		MenuSettingsTask.QuestFrame.NoDescMessage:Hide();
		MenuSettingsTask.QuestFrame.tb_TitleForce:Hide();
		MenuSettingsTask.QuestFrame.tb_TitleForce:SetText("");
		MenuSettingsTask.QuestFrame.multi_DescForce:Hide();
		_G["WCC_multiline_ST_DescForce"]:SetText("");
	end
	WCCreator_Lib.SetSizeMenuSettingsTask();
end

local function SaveTaskQuest(title, desc)
	local bOK = true;
	local settings = WCCreator_Lib.structures.SettingsTask_value;
	local NoTitleQuest = (title == nil or title == "");
	local NoDescQuest  = (desc == nil or desc == "");
	if (NoTitleQuest == true or NoDescQuest == true) then
		if (not MenuSettingsTask.QuestFrame.NoDescMessage:IsShown()) then
			settings.title = title;
			settings.desc  = desc;
		end
		settings.bForceQuest  = true;
		settings.bAutoRefresh = NoTitleQuest;
		bOK = false;
		if (settings.title ~= ""  and settings.desc ~= "" and
			settings.title ~= nil and settings.desc ~= nil) then
			bOK = true;
		end
	else
		settings.title        = title;
		settings.desc         = desc;
		settings.bForceQuest  = false;
		settings.bAutoRefresh = false;
		bOK = true;
	end
	WCCreator_Lib.ShowForceQuest();
	return bOK;
end

local function SaveSettingsToTask(category)
	if (CheckIfErrorExists() == true) then
		local settings = WCCreator_Lib.structures.SettingsTask_value;
		if (category == "hf") then
			_, settings.title = GetAchievementInfo(tonumber(settings.idHF));
		elseif (category == "need") then
			settings.title = "|T"..settings.itemInfo[4]..":16|t x"..tostring(settings.nbRequired)..core.L["Required"];
		end
		local arrTasks = settings.info.arrTasks;
		arrTasks[settings.info.allIdFromTask[4]].title                = settings.title;
		arrTasks[settings.info.allIdFromTask[4]].tooltipText          = settings.desc;
		arrTasks[settings.info.allIdFromTask[4]].idHF                 = settings.idHF;
		arrTasks[settings.info.allIdFromTask[4]].idQuest              = settings.idQuest;
		arrTasks[settings.info.allIdFromTask[4]].bForceQuest          = settings.bForceQuest;
		arrTasks[settings.info.allIdFromTask[4]].bAutoRefresh         = settings.bAutoRefresh;
		arrTasks[settings.info.allIdFromTask[4]].taskType             = settings.category;
		arrTasks[settings.info.allIdFromTask[4]].idItem               = settings.idItem;
		arrTasks[settings.info.allIdFromTask[4]].nbRequired           = settings.nbRequired;
		arrTasks[settings.info.allIdFromTask[4]].obtentionType        = settings.obtentionType;
		arrTasks[settings.info.allIdFromTask[4]].obtention_loot       = settings.obtention_loot;
		arrTasks[settings.info.allIdFromTask[4]].obtention_vendor     = settings.obtention_vendor;
		arrTasks[settings.info.allIdFromTask[4]].obtention_create     = settings.obtention_create;
		arrTasks[settings.info.allIdFromTask[4]].obtention_profession = settings.obtention_profession;
		arrTasks[settings.info.allIdFromTask[4]].obtention_IdQuest    = settings.obtention_IdQuest;
		arrTasks[settings.info.allIdFromTask[4]].obtention_titleQuest = settings.obtention_titleQuest;
		arrTasks[settings.info.allIdFromTask[4]].obtention_IdHF       = settings.obtention_IdHF;
		arrTasks[settings.info.allIdFromTask[4]].obtention_titleHF    = settings.obtention_titleHF;
		arrTasks[settings.info.allIdFromTask[4]].validationType       = settings.validationType;
		arrTasks[settings.info.allIdFromTask[4]].validationId         = settings.validationId;
		if (settings.validationModId == "" or settings.validationModId == nil) then
			settings.validationModId = 0;
		end
		arrTasks[settings.info.allIdFromTask[4]].validationModId      = settings.validationModId;
		arrTasks[settings.info.allIdFromTask[4]].itemInfo             = settings.itemInfo;
		WC_Lib.RefreshStepTasks(arrTasks, "WCC", settings.info.allIdFromTask[1], settings.info.allIdFromTask[2], settings.info.allIdFromTask[3], nil)
		MenuSettingsTask:Hide();
		WCCreator_Lib.UpdateVersionGuide(nil, settings.info.allIdFromTask[1]);
		PlaySound("83", "sfx");
	end
end

local questLoadFrame = CreateFrame("Frame");
questLoadFrame.bOK = false;
questLoadFrame:RegisterEvent("QUEST_DATA_LOAD_RESULT");
questLoadFrame:SetScript("OnEvent", function (self, event, questID, success)
	if (self.bOK == true) then
		self.bOK = false;
		local title = C_QuestLog.GetTitleForQuestID(questID);
		local desc  = WC_Lib.GetObjectivesQuest(questID);
		local bOk = SaveTaskQuest(title, desc);
		MenuSettingsTask.SaveBtn:Enable();
		if (bOk == true) then
			SaveSettingsToTask();
		end
	end
end);

local function SaveTask()
	local settings = WCCreator_Lib.structures.SettingsTask_value;
	if (settings.category == "custom") then
		SaveSettingsToTask();
	elseif (settings.category == "hf") then
		SaveSettingsToTask("hf");
	elseif (settings.category == "quest") then
		local id = settings.idQuest;
		if (id ~= "" and tonumber(settings.idQuest) < 2147483647) then
			MenuSettingsTask.SaveBtn:Disable();
			questLoadFrame.bOK = true;
			C_QuestLog.RequestLoadQuestByID(tonumber(id));
		end
	elseif (settings.category == "need") then
		SaveSettingsToTask("need");
	end
end

local function MenuSettingsTaskEmpty()
	return;
end

local function MenuSettingsTaskFill(currentTask)
	local settingsValue    = WCCreator_Lib.structures.SettingsTask_value;
	
	settingsValue.title                = "";
	settingsValue.desc                 = "";
	settingsValue.bForceQuest          = false;
	settingsValue.bAutoRefresh         = false;
	settingsValue.idQuest              = "";
	settingsValue.idHF                 = "";
	settingsValue.idItem               = "";
	settingsValue.obtentionType        = "none";
	settingsValue.obtention_IdQuest    = "";
	settingsValue.obtention_titleQuest = "";
	settingsValue.obtention_IdHF       = "";
	settingsValue.obtention_titleHF    = "";
	settingsValue.obtention_loot       = {};
	settingsValue.obtention_vendor     = {};
	settingsValue.obtention_create     = {};
	settingsValue.obtention_profession = "none";
	settingsValue.validationType       = "manual";
	settingsValue.validationId         = "";
	settingsValue.validationModId      = "";
	settingsValue.nbRequired           = "";
	settingsValue.itemInfo             = {};
	
	settingsValue.category = currentTask.taskType;
	MenuSettingsTask.AchievFrame:Hide();
	MenuSettingsTask.QuestFrame:Hide();
	MenuSettingsTask.CustomFrame:Hide();
	MenuSettingsTask.ItemFrame:Hide();
	
	local guideID = settingsValue.info.allIdFromTask[1];
	MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame.idGuide   = guideID;
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame.idGuide = guideID;
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame.idGuide = guideID;
	
	--- SET UP DEFAULT ---
	WCCreator_Lib.SwitchValidEdit(MenuSettingsTask.ItemFrame.tb_IdItem:GetName(), true)
	MenuSettingsTask.ItemFrame.fs_Obtention_desc:Hide();
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuest:Hide();
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuestValid:Hide();
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHF:Hide();
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHFValid:Hide();
	MenuSettingsTask.ItemFrame.LootObtentionFrame:Hide();
	MenuSettingsTask.ItemFrame.VendorObtentionFrame:Hide();
	MenuSettingsTask.ItemFrame.CreateObtentionFrame:Hide();
	MenuSettingsTask.ItemFrame.tb_IdValidation:Hide();
	MenuSettingsTask.ItemFrame.tb_IdValidation:SetWidth(210);
	MenuSettingsTask.ItemFrame.tb_ModIdValidation:Hide();
	MenuSettingsTask.ItemFrame.chbx_HiddenQuest:Hide();
	
	UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Obtention"], "|cFFF5CC00"..core.L["Obtention"]..core.L["2points"].."|r " ..core.L["Non précisé"]);
	UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Obtention_Professions"], "|cFFF5CC00"..core.L["Professions"]..core.L["2points"].."|r " ..core.L["Aucun"]);
	UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Validation"], "|cFFF5CC00"..core.L["Validation"]..core.L["2points"].."|r " ..core.L["Manuelle"]);
	MenuSettingsTask.ItemFrame.subtitle3:SetPoint("TOP", MenuSettingsTask.ItemFrame.ddm_Obtention, "BOTTOM", 0, -15);
	--- END SET UP DEFAULT ---
	
	if (settingsValue.category == "custom") then
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Category"], "|cFFF5CC00"..core.L["Catégorie"]..core.L["2points"].."|r " ..core.L["Custom"]);
		settingsValue.title = currentTask.title;
		settingsValue.desc  = currentTask.tooltipText;
		MenuSettingsTask.CustomFrame:Show();
	elseif (settingsValue.category == "hf") then
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Category"], "|cFFF5CC00"..core.L["Catégorie"]..core.L["2points"].."|r " ..core.L["Haut-fait"]);
		settingsValue.idHF = currentTask.idHF;
		MenuSettingsTask.AchievFrame:Show()
	elseif (settingsValue.category == "quest") then
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Category"], "|cFFF5CC00"..core.L["Catégorie"]..core.L["2points"].."|r " ..core.L["Quest"]);
		settingsValue.bForceQuest  = currentTask.bForceQuest or false;
		settingsValue.bAutoRefresh = currentTask.bAutoRefresh or false;
		settingsValue.idQuest      = currentTask.idQuest or "";
		if (currentTask.bForceQuest == true) then
			settingsValue.title = currentTask.title or "";
			settingsValue.desc  = currentTask.tooltipText or "";
		end		
		MenuSettingsTask.QuestFrame:Show()
		WCCreator_Lib.ShowForceQuest();
	elseif (settingsValue.category == "need") then
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Category"], "|cFFF5CC00"..core.L["Catégorie"]..core.L["2points"].."|r " ..core.L["Item"]);
		settingsValue.idItem                         = currentTask.idItem or "";
		settingsValue.obtentionType                  = currentTask.obtentionType or "none";
		settingsValue.nbRequired                     = currentTask.nbRequired or "";
		settingsValue.itemInfo                       = currentTask.itemInfo or {};
		MenuSettingsTask.ItemFrame.itemIcon.itemLink = currentTask.itemInfo[2] or 0;
		settingsValue.validationType                 = currentTask.validationType or "manual";
		if (currentTask.idItem ~= "" and currentTask.idItem ~= nil) then
			WCCreator_Lib.SwitchValidEdit(MenuSettingsTask.ItemFrame.tb_IdItem:GetName(), false)
		else
			WCCreator_Lib.SwitchValidEdit(MenuSettingsTask.ItemFrame.tb_IdItem:GetName(), true)
		end
		local obtentionType_ddmText = "";
		if settingsValue.obtentionType == "none" then obtentionType_ddmText = core.L["Non précisé"]
		elseif settingsValue.obtentionType == "loot" then obtentionType_ddmText = core.L["DroppedBy"]
		elseif settingsValue.obtentionType == "vendor" then obtentionType_ddmText = core.L["SoldBy"]
		elseif settingsValue.obtentionType == "create" then obtentionType_ddmText = core.L["CreatedBy"]
		elseif settingsValue.obtentionType == "quest" then obtentionType_ddmText = core.L["FinishQuest"]
		elseif settingsValue.obtentionType == "hf" then obtentionType_ddmText = core.L["FinishHF"]
		end;
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Obtention"], "|cFFF5CC00"..core.L["Obtention"]..core.L["2points"].."|r " ..obtentionType_ddmText);
		if (settingsValue.obtentionType ~= "none") then
			MenuSettingsTask.ItemFrame.fs_Obtention_desc:Show();
		end
		if (settingsValue.obtentionType == "loot") then
			settingsValue.obtention_loot = currentTask.obtention_loot or {};
			WCCreator_Lib.RefreshListOfItem(MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame, settingsValue.obtention_loot, MenuSettingsTask.arrLoot, {[1] = "nameNPC", [2] = "dropPercent"}, 1,
			function ()
				MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshNPCDroppedLoot(settingsValue.obtention_loot));
			end);
			MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshNPCDroppedLoot(settingsValue.obtention_loot));
			MenuSettingsTask.ItemFrame.LootObtentionFrame:Show();
		elseif (settingsValue.obtentionType == "vendor") then
			settingsValue.obtention_vendor = currentTask.obtention_vendor or {};
			WCCreator_Lib.RefreshListOfItem(MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame, settingsValue.obtention_vendor, MenuSettingsTask.arrVendor, nil, 1,
				function ()
					MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshNPCVendor(settingsValue.obtention_vendor));
				end);
			MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshNPCVendor(settingsValue.obtention_vendor));
			MenuSettingsTask.ItemFrame.VendorObtentionFrame:Show();
		elseif (settingsValue.obtentionType == "create") then
			settingsValue.obtention_create     = currentTask.obtention_create or {};
			settingsValue.obtention_profession = currentTask.obtention_profession or "none";
			local professionText = currentTask.obtention_profession;
			if (professionText == "none") then
				professionText = core.L["Aucun"];
			end
			UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Obtention_Professions"], "|cFFF5CC00"..core.L["Professions"]..core.L["2points"].."|r " ..professionText);
			WCCreator_Lib.RefreshListOfItem(MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame, WCCreator_Lib.structures.SettingsTask_value.obtention_create, MenuSettingsTask.arrCreate, {[1] = "idItem", [2] = "nbNeed"}, 1,
				function ()
					MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshCompoCreate(WCCreator_Lib.structures.SettingsTask_value.obtention_create, WCCreator_Lib.structures.SettingsTask_value.obtention_profession));
				end);
			MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshCompoCreate(WCCreator_Lib.structures.SettingsTask_value.obtention_create, WCCreator_Lib.structures.SettingsTask_value.obtention_profession));
			MenuSettingsTask.ItemFrame.CreateObtentionFrame:Show();	
		elseif (settingsValue.obtentionType == "quest") then
			settingsValue.obtention_IdQuest    = currentTask.obtention_IdQuest or "";
			settingsValue.obtention_titleQuest = currentTask.obtention_titleQuest or "";
			MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText("|cffffffff"..core.L["FinishQuest"].."|r"..settingsValue.obtention_titleQuest.."|cffffffff.|r");
			MenuSettingsTask.ItemFrame.tb_Obtention_IdQuestValid:Show();
			_G[MenuSettingsTask.ItemFrame.tb_Obtention_IdQuestValid:GetName().."Btn"]:Show();
			MenuSettingsTask.ItemFrame.subtitle3:SetPoint("TOP", MenuSettingsTask.ItemFrame.ddm_Obtention, "BOTTOM", 0, -90);
		elseif (settingsValue.obtentionType == "hf") then
			settingsValue.obtention_IdHF    = currentTask.obtention_IdHF or "";
			settingsValue.obtention_titleHF = currentTask.obtention_titleHF or "";
			MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText("|cffffffff"..core.L["FinishHF"].."|r"..settingsValue.obtention_titleHF.."|cffffffff.|r");
			MenuSettingsTask.ItemFrame.tb_Obtention_IdHFValid:Show();
			_G[MenuSettingsTask.ItemFrame.tb_Obtention_IdHFValid:GetName().."Btn"]:Show();
			MenuSettingsTask.ItemFrame.subtitle3:SetPoint("TOP", MenuSettingsTask.ItemFrame.ddm_Obtention, "BOTTOM", 0, -90);
		end
		settingsValue.validationId    = currentTask.validationId or "";
		settingsValue.validationModId = currentTask.validationModId or "";
		MenuSettingsTask.ItemFrame.tb_IdValidation:Show();		
		MenuSettingsTask.ItemFrame.tb_IdValidation:SetPoint("TOP", MenuSettingsTask.ItemFrame.ddm_Validation, "BOTTOM", 0, -15);
		local validationType_ddmText = "";
		if settingsValue.validationType == "manual"       then validationType_ddmText = core.L["Manuelle"]      ; MenuSettingsTask.ItemFrame.tb_IdValidation:Hide();
		elseif settingsValue.validationType == "quest"    then
			settingsValue.bAutoRefresh = currentTask.bAutoRefresh or false;
			validationType_ddmText = core.L["Avec quête"];
			MenuSettingsTask.ItemFrame.tb_IdValidation:Show();
			MenuSettingsTask.ItemFrame.tb_IdValidation:SetWidth(150);
			MenuSettingsTask.ItemFrame.tb_IdValidation:SetPoint("TOP", MenuSettingsTask.ItemFrame.ddm_Validation, "BOTTOM", -20, -15);
			MenuSettingsTask.ItemFrame.chbx_HiddenQuest:Show();
		elseif settingsValue.validationType == "hf"       then validationType_ddmText = core.L["Avec haut-fait"];
		elseif settingsValue.validationType == "mounts"    then validationType_ddmText = core.L["Avec monture"]  ;
		elseif settingsValue.validationType == "pets"      then validationType_ddmText = core.L["Avec mascotte"] ;
		elseif settingsValue.validationType == "transmogs" then
			validationType_ddmText = core.L["Avec transmog"] ;
			MenuSettingsTask.ItemFrame.tb_IdValidation:Show();
			MenuSettingsTask.ItemFrame.tb_IdValidation:SetWidth(150);
			MenuSettingsTask.ItemFrame.tb_IdValidation:SetPoint("TOP", MenuSettingsTask.ItemFrame.ddm_Validation, "BOTTOM", -20, -15);
			MenuSettingsTask.ItemFrame.tb_ModIdValidation:Show();
		end;
		UIDropDownMenu_SetText(_G["WCC_dropdownmenu_ST_Validation"], "|cFFF5CC00"..core.L["Validation"]..core.L["2points"].."|r " ..validationType_ddmText);
		MenuSettingsTask.ItemFrame:Show();
	end
	
	--- SET TEXT POPUP ---
	MenuSettingsTask.CustomFrame.tb_Title:SetText(settingsValue.title);
	_G["WCC_multiline_ST_Desc"]:SetText(settingsValue.desc);
	MenuSettingsTask.AchievFrame.tb_IdAchiev:SetText(settingsValue.idHF);
	MenuSettingsTask.QuestFrame.tb_IdQuest:SetText(settingsValue.idQuest);
	MenuSettingsTask.ItemFrame.tb_IdItem:SetText(settingsValue.idItem);
	MenuSettingsTask.ItemFrame.tb_IdItemValid:SetText(settingsValue.idItem);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuest:SetText(settingsValue.obtention_IdQuest);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuestValid:SetText(settingsValue.obtention_IdQuest);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHF:SetText(settingsValue.obtention_IdHF);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHFValid:SetText(settingsValue.obtention_IdHF);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_nameNPC:SetText("");
	MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_dropPercent:SetText("");
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.tb_Obtention_vendorName:SetText("");
	MenuSettingsTask.ItemFrame.itemIcon:SetBackdrop({bgFile = settingsValue.itemInfo[4] or "Interface\\ICONS\\inv_misc_questionmark"});
	MenuSettingsTask.ItemFrame.tb_NbRequired:SetText(settingsValue.nbRequired);
	MenuSettingsTask.ItemFrame.tb_IdValidation:SetText(settingsValue.validationId);
	MenuSettingsTask.ItemFrame.tb_ModIdValidation:SetText(settingsValue.validationModId);
	MenuSettingsTask.ItemFrame.chbx_HiddenQuest:SetChecked(currentTask.bAutoRefresh or false);
	
	WCCreator_Lib.SetSizeMenuSettingsTask();
end

local function CreateMenuSettingsTask(self)
	MenuSettingsTask = CreateFrame("Frame", "WCC_MenuSettingsTaskFrame", UIParent, BackdropTemplateMixin and "BackdropTemplate");
	MenuSettingsTask:SetFrameLevel(514);
	MenuSettingsTask:SetMovable(true);
	MenuSettingsTask:EnableMouse(true);
	MenuSettingsTask:RegisterForDrag("LeftButton");
	MenuSettingsTask:SetScript("OnDragStart", MenuSettingsTask.StartMoving);
	MenuSettingsTask:SetScript("OnDragStop", MenuSettingsTask.StopMovingOrSizing);
	MenuSettingsTask:SetPoint("CENTER", UIParent, "CENTER");
	MenuSettingsTask:SetBackdrop({bgFile = "Interface/Collections/CollectionsBackgroundTile",
							edgeFile = "Interface/FriendsFrame/UI-Toast-Border",
							edgeSize = 16,
							insets = { left = 7, right = 5, top = 5, bottom = 6 }});
							
	MenuSettingsTask.close = CreateFrame("Button", nil, MenuSettingsTask, "UIPanelCloseButton");
	MenuSettingsTask.close:SetSize(32, 32);
	MenuSettingsTask.close:SetPoint("TOPRIGHT", MenuSettingsTask, "TOPRIGHT", -5, -5);
	MenuSettingsTask.close:SetScript("OnClick", function(self)
		MenuSettingsTask:Hide();
		PlaySound("854", "sfx");
	end);
	
	MenuSettingsTask.title = MenuSettingsTask:CreateFontString(nil, "OVERLAY", MenuSettingsTask);
	MenuSettingsTask.title:SetFontObject("GameFontHighlightLarge");
	MenuSettingsTask.title:SetText(core.L["Paramètres Tâche"]);
	MenuSettingsTask.title:SetPoint("TOP", MenuSettingsTask, "TOP", 0, -13);
	
	MenuSettingsTask.ddm_Category = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Category, MenuSettingsTask);
	MenuSettingsTask.ddm_Category:SetPoint("TOP", MenuSettingsTask, "TOP", 0, -40);

	----- CUSTOM PART -----
	MenuSettingsTask.CustomFrame = CreateFrame("Frame", nil, MenuSettingsTask, BackdropTemplateMixin and "BackdropTemplate");
	MenuSettingsTask.CustomFrame:SetSize(350, 210);
	MenuSettingsTask.CustomFrame:SetPoint("TOP", MenuSettingsTask.ddm_Category, "BOTTOM");
	MenuSettingsTask.CustomFrame.tb_Title = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Title, MenuSettingsTask.CustomFrame);
	MenuSettingsTask.CustomFrame.tb_Title:SetPoint("TOP", MenuSettingsTask.CustomFrame, "TOP", 0, -20);
	MenuSettingsTask.CustomFrame.multi_Desc = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Desc, MenuSettingsTask.CustomFrame);
	MenuSettingsTask.CustomFrame.multi_Desc:SetPoint("TOP", MenuSettingsTask.CustomFrame.tb_Title, "BOTTOM", 0, -30);
	MenuSettingsTask.CustomFrame:Hide();
	
	----- HF PART -----
	MenuSettingsTask.AchievFrame = CreateFrame("Frame", nil, MenuSettingsTask, BackdropTemplateMixin and "BackdropTemplate");
	MenuSettingsTask.AchievFrame:SetSize(350, 210);
	MenuSettingsTask.AchievFrame:SetPoint("TOP", MenuSettingsTask.ddm_Category, "BOTTOM");
	MenuSettingsTask.AchievFrame.tb_IdAchiev = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_IdAchiev, MenuSettingsTask.AchievFrame);
	MenuSettingsTask.AchievFrame.tb_IdAchiev:SetPoint("TOP", MenuSettingsTask.AchievFrame, "TOP", 0, -20);
	MenuSettingsTask.AchievFrame:Hide();
	
	----- QUEST PART -----
	MenuSettingsTask.QuestFrame = CreateFrame("Frame", nil, MenuSettingsTask, BackdropTemplateMixin and "BackdropTemplate");
	MenuSettingsTask.QuestFrame:SetSize(350, 210);
	MenuSettingsTask.QuestFrame:SetPoint("TOP", MenuSettingsTask.ddm_Category, "BOTTOM");
	MenuSettingsTask.QuestFrame.tb_IdQuest = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_IdQuest, MenuSettingsTask.QuestFrame);
	MenuSettingsTask.QuestFrame.tb_IdQuest:SetPoint("TOP", MenuSettingsTask.QuestFrame, "TOP", 0, -20);
	MenuSettingsTask.QuestFrame.NoDescMessage = MenuSettingsTask.QuestFrame:CreateFontString(nil, "OVERLAY", MenuSettingsTask.QuestFrame);
	MenuSettingsTask.QuestFrame.NoDescMessage:SetSize(MenuSettingsTask.QuestFrame:GetWidth(), 0);
	MenuSettingsTask.QuestFrame.NoDescMessage:SetFontObject("GameFontNormalSmall");
	MenuSettingsTask.QuestFrame.NoDescMessage:SetPoint("TOP", MenuSettingsTask.QuestFrame.tb_IdQuest, "BOTTOM", 0, -10);
	MenuSettingsTask.QuestFrame.NoDescMessage:SetText("La quête ne possède pas de titre et/ou de description, veuillez remplir les champs suivants.\n\n|cffff0000Attention, il est possible que l'ID rentré ne correspond à aucune quête.|r");
	MenuSettingsTask.QuestFrame.NoDescMessage:Hide();
	MenuSettingsTask.QuestFrame.tb_TitleForce = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_TitleForce, MenuSettingsTask.QuestFrame);
	MenuSettingsTask.QuestFrame.tb_TitleForce:SetPoint("TOP", MenuSettingsTask.QuestFrame.NoDescMessage, "BOTTOM", 0, -20);
	MenuSettingsTask.QuestFrame.multi_DescForce = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_DescForce, MenuSettingsTask.QuestFrame);
	MenuSettingsTask.QuestFrame.multi_DescForce:SetPoint("TOP", MenuSettingsTask.QuestFrame.tb_TitleForce, "BOTTOM", 0, -20);
	MenuSettingsTask.QuestFrame.tb_TitleForce:Hide();
	MenuSettingsTask.QuestFrame.multi_DescForce:Hide();
	MenuSettingsTask.QuestFrame:Hide();
	
	----- ITEM PART -----
	MenuSettingsTask.ItemFrame = CreateFrame("Frame", nil, MenuSettingsTask, BackdropTemplateMixin and "BackdropTemplate");
	MenuSettingsTask.ItemFrame:SetSize(350, 210);
	MenuSettingsTask.ItemFrame:SetPoint("TOP", MenuSettingsTask.ddm_Category, "BOTTOM");
	
	MenuSettingsTask.ItemFrame.subtitle1 = WCCreator_Lib.CreateTitle(core.L["Général"], MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.subtitle1:SetPoint("TOP", MenuSettingsTask.ItemFrame, "TOP", 0, -5);
	
	MenuSettingsTask.ItemFrame.tb_IdItem = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_IdItem, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.tb_IdItem:SetPoint("TOPLEFT", MenuSettingsTask.ItemFrame.subtitle1, "TOPLEFT", 65, -40);
	MenuSettingsTask.ItemFrame.tb_IdItemValid = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_IdItemValid, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.tb_IdItemValid:SetPoint("TOPLEFT", MenuSettingsTask.ItemFrame.subtitle1, "TOPLEFT", 65, -40);
	WCCreator_Lib.TextBoxSetDisable(MenuSettingsTask.ItemFrame.tb_IdItemValid);
	MenuSettingsTask.ItemFrame.tb_IdItemValid:Hide();
	MenuSettingsTask.ItemFrame.itemIcon = CreateFrame("Frame", nil, MenuSettingsTask.ItemFrame, BackdropTemplateMixin and "BackdropTemplate");
	MenuSettingsTask.ItemFrame.itemIcon:SetSize(24, 24);
	MenuSettingsTask.ItemFrame.itemIcon:SetBackdrop({bgFile = "Interface\\ICONS\\inv_misc_questionmark"});
	MenuSettingsTask.ItemFrame.itemIcon.itemLink = 0;
	MenuSettingsTask.ItemFrame.itemIcon:SetScript("OnEnter", WC_Lib.OnEnterIconItem);
	MenuSettingsTask.ItemFrame.itemIcon:SetScript("OnLeave", WC_Lib.OnLeave);
	MenuSettingsTask.ItemFrame.itemIcon:SetPoint("LEFT", MenuSettingsTask.ItemFrame.tb_IdItem, "RIGHT", 12, 0);
	MenuSettingsTask.ItemFrame.tb_NbRequired = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_NbRequired, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.tb_NbRequired:SetPoint("LEFT", MenuSettingsTask.ItemFrame.tb_IdItem, "RIGHT", 55, 0);
	MenuSettingsTask.ItemFrame.tb_NbRequired:SetText("1");
	
	MenuSettingsTask.ItemFrame.subtitle2 = WCCreator_Lib.CreateTitle(core.L["Obtention"], MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.subtitle2:SetPoint("TOP", MenuSettingsTask.ItemFrame, "TOP", 0, -105);
	MenuSettingsTask.ItemFrame.ddm_Obtention = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.ddm_Obtention:SetPoint("TOP", MenuSettingsTask.ItemFrame.subtitle2, "BOTTOM", 0, -10);
	MenuSettingsTask.ItemFrame.fs_Obtention_desc = MenuSettingsTask:CreateFontString(nil, "OVERLAY", MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetFontObject("GameFontNormalSmall");
	MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText("|cffffffff"..core.L["FinishQuest"].."|r |cffffffff.|r");
	MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetPoint("TOP", MenuSettingsTask.ItemFrame.ddm_Obtention, "BOTTOM", 0, -5);
	MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetSize(MenuSettingsTask.ItemFrame:GetWidth(), 0);
	MenuSettingsTask.ItemFrame.fs_Obtention_desc:Hide();
	
	MenuSettingsTask.ItemFrame.subtitle3 = WCCreator_Lib.CreateTitle(core.L["Validation"], MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.subtitle3:SetPoint("TOP", MenuSettingsTask.ItemFrame.ddm_Obtention, "BOTTOM", 0, -15);
	
	----- ITEM PART => LOOT OBTENTION -----
	MenuSettingsTask.ItemFrame.LootObtentionFrame = CreateFrame("Frame", nil, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.LootObtentionFrame:SetSize(350, 25);
	MenuSettingsTask.ItemFrame.LootObtentionFrame:SetPoint("TOP", MenuSettingsTask.ItemFrame.fs_Obtention_desc, "BOTTOM", 0, -15);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_nameNPC = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_lootNameNPC, MenuSettingsTask.ItemFrame.LootObtentionFrame);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_nameNPC:SetPoint("TOPLEFT", MenuSettingsTask.ItemFrame.LootObtentionFrame, "TOPLEFT", 40, 0);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_dropPercent = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_dropPercent, MenuSettingsTask.ItemFrame.LootObtentionFrame);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_dropPercent:SetPoint("LEFT", MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_nameNPC, "RIGHT", 10, 0);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.AddBtn = CreateFrame("Button", nil, MenuSettingsTask.ItemFrame.LootObtentionFrame, "UIPanelButtonTemplate");
	MenuSettingsTask.ItemFrame.LootObtentionFrame.AddBtn:SetSize(60, 25);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.AddBtn:SetText(core.L["Ajouter"]);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.AddBtn:Disable();
	MenuSettingsTask.ItemFrame.LootObtentionFrame.AddBtn:SetPoint("LEFT", MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_dropPercent, "RIGHT", 15, 0);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.AddBtn:SetScript("OnClick", function(self)
		local arrPos = #WCCreator_Lib.structures.SettingsTask_value.obtention_loot + 1;
		WCCreator_Lib.structures.SettingsTask_value.obtention_loot[arrPos] = {};
		WCCreator_Lib.structures.SettingsTask_value.obtention_loot[arrPos].nameNPC     = MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_nameNPC:GetText();
		WCCreator_Lib.structures.SettingsTask_value.obtention_loot[arrPos].dropPercent = MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_dropPercent:GetText();
		WCCreator_Lib.RefreshListOfItem(MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame, WCCreator_Lib.structures.SettingsTask_value.obtention_loot, MenuSettingsTask.arrLoot, {[1] = "nameNPC", [2] = "dropPercent"}, 1,
			function ()
				MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshNPCDroppedLoot(WCCreator_Lib.structures.SettingsTask_value.obtention_loot));
			end);
		MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshNPCDroppedLoot(WCCreator_Lib.structures.SettingsTask_value.obtention_loot));
		WCCreator_Lib.UpdateVersionGuide(nil, WCCreator_Lib.structures.SettingsTask_value.info.allIdFromTask[1]);
	end);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame = CreateFrame("Frame", "WCC_MenuSettingsTaskFrame_ListLoot", MenuSettingsTask.ItemFrame.LootObtentionFrame, BackdropTemplateMixin and "BackdropTemplate");
	MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame:SetSize(MenuSettingsTask.ItemFrame.LootObtentionFrame:GetWidth()-40, 25);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame:SetPoint("TOPLEFT", MenuSettingsTask.ItemFrame.LootObtentionFrame.tb_Obtention_nameNPC, "BOTTOMLEFT", -10, -10);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame:SetScript("OnSizeChanged", function (self, width, height)
		WCCreator_Lib.SetSizeMenuSettingsTask();
	end);
	MenuSettingsTask.ItemFrame.LootObtentionFrame.ListFrame:SetBackdrop({bgFile = ""}); -- <= Obligé sinon ne s'affiche pas
	MenuSettingsTask.ItemFrame.LootObtentionFrame:Hide();
	----- ITEM PART => VENDOR OBTENTION -----
	MenuSettingsTask.ItemFrame.VendorObtentionFrame = CreateFrame("Frame", nil, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame:SetSize(350, 75);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame:SetPoint("TOP", MenuSettingsTask.ItemFrame.fs_Obtention_desc, "BOTTOM", 0, -15);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.tb_Obtention_vendorName = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_vendorName, MenuSettingsTask.ItemFrame.VendorObtentionFrame);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.tb_Obtention_vendorName:SetPoint("TOPLEFT", MenuSettingsTask.ItemFrame.VendorObtentionFrame, "TOPLEFT", 40, 0);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.AddBtn = CreateFrame("Button", nil, MenuSettingsTask.ItemFrame.VendorObtentionFrame, "UIPanelButtonTemplate");
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.AddBtn:SetSize(60, 25);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.AddBtn:SetText(core.L["Ajouter"]);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.AddBtn:Disable();
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.AddBtn:SetPoint("LEFT", MenuSettingsTask.ItemFrame.VendorObtentionFrame.tb_Obtention_vendorName, "RIGHT", 15, 0);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.AddBtn:SetScript("OnClick", function(self)
		local arrPos = #WCCreator_Lib.structures.SettingsTask_value.obtention_vendor + 1;
		WCCreator_Lib.structures.SettingsTask_value.obtention_vendor[arrPos] = MenuSettingsTask.ItemFrame.VendorObtentionFrame.tb_Obtention_vendorName:GetText();
		WCCreator_Lib.RefreshListOfItem(MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame, WCCreator_Lib.structures.SettingsTask_value.obtention_vendor, MenuSettingsTask.arrVendor, nil, 1,
				function ()
					MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshNPCVendor(WCCreator_Lib.structures.SettingsTask_value.obtention_vendor));
				end);
		MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshNPCVendor(WCCreator_Lib.structures.SettingsTask_value.obtention_vendor));
		WCCreator_Lib.UpdateVersionGuide(nil, WCCreator_Lib.structures.SettingsTask_value.info.allIdFromTask[1]);
	end);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame = CreateFrame("Frame", "WCC_MenuSettingsTaskFrame_ListVendor", MenuSettingsTask.ItemFrame.VendorObtentionFrame, BackdropTemplateMixin and "BackdropTemplate");
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame:SetSize(MenuSettingsTask.ItemFrame.VendorObtentionFrame:GetWidth()-40, 25);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame:SetPoint("TOPLEFT", MenuSettingsTask.ItemFrame.VendorObtentionFrame.tb_Obtention_vendorName, "BOTTOMLEFT", -10, -10);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame:SetScript("OnSizeChanged", function (self, width, height)
		WCCreator_Lib.SetSizeMenuSettingsTask();
	end);
	MenuSettingsTask.ItemFrame.VendorObtentionFrame.ListFrame:SetBackdrop({bgFile = ""}); -- <= Obligé sinon ne s'affiche pas
	MenuSettingsTask.ItemFrame.VendorObtentionFrame:Hide();
	----- ITEM PART => CREATE OBTENTION -----
	MenuSettingsTask.ItemFrame.CreateObtentionFrame = CreateFrame("Frame", nil, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame:SetSize(350, 25);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame:SetPoint("TOP", MenuSettingsTask.ItemFrame.fs_Obtention_desc, "BOTTOM", 0, -15);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.ddm_Obtention_Professions = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_Professions, MenuSettingsTask.ItemFrame.CreateObtentionFrame);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.ddm_Obtention_Professions:SetPoint("TOP", MenuSettingsTask.ItemFrame.fs_Obtention_desc, "BOTTOM", 0, -10);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.tb_Obtention_idItem = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_createIdItem, MenuSettingsTask.ItemFrame.CreateObtentionFrame);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.tb_Obtention_idItem:SetPoint("TOPLEFT", MenuSettingsTask.ItemFrame.CreateObtentionFrame, "TOPLEFT", 40, -40);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.tb_Obtention_nbNeed = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_createNbNeed, MenuSettingsTask.ItemFrame.CreateObtentionFrame);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.tb_Obtention_nbNeed:SetPoint("LEFT", MenuSettingsTask.ItemFrame.CreateObtentionFrame.tb_Obtention_idItem, "RIGHT", 10, 0);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.AddBtn = CreateFrame("Button", nil, MenuSettingsTask.ItemFrame.CreateObtentionFrame, "UIPanelButtonTemplate");
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.AddBtn:SetSize(60, 25);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.AddBtn:SetText(core.L["Ajouter"]);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.AddBtn:Disable();
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.AddBtn:SetPoint("LEFT", MenuSettingsTask.ItemFrame.CreateObtentionFrame.tb_Obtention_nbNeed, "RIGHT", 15, 0);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.AddBtn:SetScript("OnClick", function(self)
		local id = MenuSettingsTask.ItemFrame.CreateObtentionFrame.tb_Obtention_idItem:GetText();
		local item = Item:CreateFromItemID(tonumber(id));
		local isEmpty = item:IsItemEmpty();
		if (isEmpty == false) then
			MenuSettingsTask.ItemFrame.CreateObtentionFrame.AddBtn:Disable();
			item:ContinueOnItemLoad(function()
				local arrPos = #WCCreator_Lib.structures.SettingsTask_value.obtention_create + 1;
				WCCreator_Lib.structures.SettingsTask_value.obtention_create[arrPos] = {};
				WCCreator_Lib.structures.SettingsTask_value.obtention_create[arrPos].idItem = id;
				WCCreator_Lib.structures.SettingsTask_value.obtention_create[arrPos].nbNeed = MenuSettingsTask.ItemFrame.CreateObtentionFrame.tb_Obtention_nbNeed:GetText();
				WCCreator_Lib.RefreshListOfItem(MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame, WCCreator_Lib.structures.SettingsTask_value.obtention_create, MenuSettingsTask.arrCreate, {[1] = "idItem", [2] = "nbNeed"}, 1,
					function ()
						MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshCompoCreate(WCCreator_Lib.structures.SettingsTask_value.obtention_create, WCCreator_Lib.structures.SettingsTask_value.obtention_profession));
					end);
				MenuSettingsTask.ItemFrame.fs_Obtention_desc:SetText(WC_Lib.RefreshCompoCreate(WCCreator_Lib.structures.SettingsTask_value.obtention_create, WCCreator_Lib.structures.SettingsTask_value.obtention_profession));	
				MenuSettingsTask.ItemFrame.CreateObtentionFrame.AddBtn:Enable();
				WCCreator_Lib.UpdateVersionGuide(nil, WCCreator_Lib.structures.SettingsTask_value.info.allIdFromTask[1]);
			end)
		else
			UIErrorsFrame:AddMessage(core.L["ErrorNoFindID"], 1, 0, 0);
			PlaySound("47355", "sfx", true);
		end
	end);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame = CreateFrame("Frame", "WCC_MenuSettingsTaskFrame_ListCreate", MenuSettingsTask.ItemFrame.CreateObtentionFrame, BackdropTemplateMixin and "BackdropTemplate");
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame:SetSize(MenuSettingsTask.ItemFrame.CreateObtentionFrame:GetWidth()-40, 25);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame:SetPoint("TOPLEFT", MenuSettingsTask.ItemFrame.CreateObtentionFrame.tb_Obtention_idItem, "BOTTOMLEFT", -10, -10);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame:SetScript("OnSizeChanged", function (self, width, height)
		WCCreator_Lib.SetSizeMenuSettingsTask();
	end);
	MenuSettingsTask.ItemFrame.CreateObtentionFrame.ListFrame:SetBackdrop({bgFile = ""}); -- <= Obligé sinon ne s'affiche pas
	MenuSettingsTask.ItemFrame.CreateObtentionFrame:Hide();
	----- ITEM PART => QUEST OBTENTION -----
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuest = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_IdQuest, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuest:SetPoint("TOP", MenuSettingsTask.ItemFrame.fs_Obtention_desc, "BOTTOM", 0, -15);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuest:Hide();
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuestValid = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_IdQuestValid, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuestValid:SetPoint("TOP", MenuSettingsTask.ItemFrame.fs_Obtention_desc, "BOTTOM", 0, -15);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdQuestValid:Hide();
	WCCreator_Lib.TextBoxSetDisable(MenuSettingsTask.ItemFrame.tb_Obtention_IdQuestValid);
	----- ITEM PART => HF OBTENTION -----
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHF = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_IdHF, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHF:SetPoint("TOP", MenuSettingsTask.ItemFrame.fs_Obtention_desc, "BOTTOM", 0, -15);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHF:Hide();
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHFValid = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Obtention_IdHFValid, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHFValid:SetPoint("TOP", MenuSettingsTask.ItemFrame.fs_Obtention_desc, "BOTTOM", 0, -15);
	MenuSettingsTask.ItemFrame.tb_Obtention_IdHFValid:Hide();
	WCCreator_Lib.TextBoxSetDisable(MenuSettingsTask.ItemFrame.tb_Obtention_IdHFValid);
	
	
	MenuSettingsTask.ItemFrame.ddm_Validation = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_Validation, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.ddm_Validation:SetPoint("TOP", MenuSettingsTask.ItemFrame.subtitle3, "BOTTOM", 0, -10);
	MenuSettingsTask.ItemFrame.tb_IdValidation = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_IdValidation, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.tb_IdValidation:SetPoint("TOP", MenuSettingsTask.ItemFrame.ddm_Validation, "BOTTOM", 0, -15);
	MenuSettingsTask.ItemFrame.tb_IdValidation:Hide();
	MenuSettingsTask.ItemFrame.tb_ModIdValidation = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_ModIdValidation, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.tb_ModIdValidation:SetPoint("LEFT", MenuSettingsTask.ItemFrame.tb_IdValidation, "RIGHT", 5, 0);
	MenuSettingsTask.ItemFrame.tb_ModIdValidation:Hide();
	MenuSettingsTask.ItemFrame.chbx_HiddenQuest = WCCreator_Lib.CreateCustomFrame(WCCreator_Lib.structures.ST_HiddenQuestValidation, MenuSettingsTask.ItemFrame);
	MenuSettingsTask.ItemFrame.chbx_HiddenQuest:SetPoint("LEFT", MenuSettingsTask.ItemFrame.tb_IdValidation, "RIGHT", 5, 0);
	MenuSettingsTask.ItemFrame.chbx_HiddenQuest:Hide();
	
	MenuSettingsTask.ItemFrame:Hide();
	
	MenuSettingsTask.SaveBtn = CreateFrame("Button", nil, MenuSettingsTask, "UIPanelButtonTemplate");
	MenuSettingsTask.SaveBtn:SetSize(100, 25);
	MenuSettingsTask.SaveBtn:SetText(core.L["Sauvegarder"]);
	MenuSettingsTask.SaveBtn:SetPoint("BOTTOM", MenuSettingsTask, "BOTTOM", 0, 10);
	MenuSettingsTask.SaveBtn:SetScript("OnClick", SaveTask);
	MenuSettingsTask.SaveBtn:SetScript("OnEnter", ShowListErrorEditTask);
	MenuSettingsTask.SaveBtn:SetScript("OnLeave", WC_Lib.OnLeave);
	
	MenuSettingsTask:Hide();
	MenuSettingsTask.arrLoot   = {};
	MenuSettingsTask.arrVendor = {};
	MenuSettingsTask.arrCreate = {};
	return MenuSettingsTask;
end

function WCCreator_Lib.ToggleSettingsTask(self)
	local settingsTask = MenuSettingsTask or CreateMenuSettingsTask(self);
	if (not settingsTask:IsShown()) then		
		WCCreator_Lib.structures.SettingsTask_value.info.arrTasks      = self.arrTasks;
		WCCreator_Lib.structures.SettingsTask_value.info.allIdFromTask = self.allIdFromTask;		
		MenuSettingsTaskFill(self.arrTasks[self.allIdFromTask[4]]);
		settingsTask:Show();
		PlaySound("681", "sfx");
	end
end